@@ -55,7 +55,7 @@ capp_workbook_open (PortableServer_Servant ignore,
 		    CORBA_boolean          shared_view,
 		    CORBA_Environment     *ev)
 {
-	Workbook     *wb = application_workbook_get_by_name (file_name);
+	Workbook     *wb = gnm_app_workbook_get_by_name (file_name);
 	WorkbookView *wbv;
 
 	if (wb != NULL) {
@@ -64,7 +64,7 @@ capp_workbook_open (PortableServer_Servant ignore,
 		else
 			wbv = NULL;
 	} else {
-		CommandContext *cc = command_context_stderr_new ();
+		GnmCmdContext *cc = cmd_context_stderr_new ();
 		IOContext *io_context = gnumeric_io_context_new (cc);
 		wbv = wb_view_new_from_file (file_name, NULL, io_context, NULL);
 		g_object_unref (G_OBJECT (io_context));
@@ -78,7 +78,7 @@ static GNOME_Gnumeric_Workbooks *
 capp_workbooks (PortableServer_Servant ignore,
 		CORBA_Environment     *ev)
 {
-	GList *workbooks = application_workbook_list ();
+	GList *workbooks = gnm_app_workbook_list ();
 	int i, len = g_list_length (workbooks);
 	GNOME_Gnumeric_Workbooks *res = GNOME_Gnumeric_Workbooks__alloc ();
 	res->_length = res->_maximum = len;
@@ -103,7 +103,7 @@ capp_class_init (CorbaApplicationClass *capp)
 	capp->epv.workbook_open	= capp_workbook_open;
 }
 
-BONOBO_TYPE_FUNC_FULL (CorbaApplication, 
+static BONOBO_TYPE_FUNC_FULL (CorbaApplication, 
 		       GNOME_Gnumeric_Application,
 		       BONOBO_OBJECT_TYPE,
 		       capp);
