@@ -17,7 +17,7 @@ void excel_read_workbook (IOContext *context, WorkbookView *new_wb,
 
 typedef struct _ExcelWriteState	 ExcelWriteState;
 void		 excel_write_state_free (ExcelWriteState *ewb);
-ExcelWriteState *excel_write_state_new  (IOContext *context, WorkbookView *wbv,
+ExcelWriteState *excel_write_state_new  (IOContext *context, WorkbookView const *wbv,
 					 gboolean biff7, gboolean biff8);
 
 void excel_write_v7 (ExcelWriteState *ewb, GsfOutfile *output);
@@ -33,18 +33,8 @@ extern  ExcelPaletteEntry const excel_default_palette[];
 extern  char const *excel_builtin_formats[];
 #define EXCEL_BUILTIN_FORMAT_LEN 0x32
 
-typedef struct {
-	char const *name;
-	int num_args ; /* -1 for multi-arg */
-		       /* -2 for unknown args */
-} FormulaFuncData;
-
-extern FormulaFuncData const formula_func_data[];
-#define FORMULA_FUNC_DATA_LEN 368
-
 #define ROW_BLOCK_MAX_LEN 32
 
-typedef gboolean (*MsExcelReadGbFn) (IOContext *context, Workbook *wb, GsfInput *input);
-extern MsExcelReadGbFn ms_excel_read_gb;
+#define	CODENAME_KEY	"XL_CODENAME_utf8"
 
 #endif /* GNUMERIC_EXCEL_H */
