@@ -7,7 +7,7 @@
  * Author:
  *    Jody Goldberg (jody@gnome.org)
  *
- * (C) 2000-2001 Jody Goldberg
+ * (C) 2000-2004 Jody Goldberg
  **/
 
 #include <gnumeric-config.h>
@@ -16,15 +16,26 @@
 #include "ms-escher.h"
 #include "ms-obj.h"
 
+#include <expr-name.h>
+#include <str.h>
+#include <value.h>
+
 void
 ms_container_init (MSContainer *container, MSContainerClass const *vtbl,
-		   MSContainer *parent_container)
+		   MSContainer *parent,
+		   ExcelWorkbook *ewb, MsBiffVersion ver)
 {
 	container->vtbl = vtbl;
+	container->ver = ver;
+	container->ewb = ewb;
 	container->free_blips = TRUE;
 	container->blips = NULL;
 	container->obj_queue  = NULL;
-	container->parent_container = parent_container;
+	container->parent = parent;
+
+	container->names = NULL;
+	container->v7.externsheets = NULL;
+	container->v7.externnames = NULL;
 }
 
 void
@@ -46,13 +57,48 @@ ms_container_finalize (MSContainer *container)
 	}
 
 	if (container->obj_queue != NULL) {
-		GList *l;
-		for (l = container->obj_queue; l != NULL; l = l->next)
-			ms_obj_delete (l->data);
+		GSList *ptr;
+		for (ptr = container->obj_queue; ptr != NULL; ptr = ptr->next)
+			ms_obj_delete (ptr->data);
 
-		g_list_free (container->obj_queue);
+		g_slist_free (container->obj_queue);
 		container->obj_queue = NULL;
 	}
+
+	if (container->v7.externsheets != NULL) {
+		g_ptr_array_free (container->v7.externsheets, TRUE);
+		container->v7.externsheets = NULL;
+	}
+	if (container->v7.externnames != NULL) {
+		for (i = container->v7.externnames->len; i-- > 0 ; )
+			if (g_ptr_array_index (container->v7.externnames, i) != NULL) {
+				GnmNamedExpr *nexpr = g_ptr_array_index (container->v7.externnames, i);
+				if (nexpr != NULL) {
+					/* NAME placeholders need removal, EXTERNNAME placeholders
+					 * will no be active */
+					if (nexpr->active && nexpr->is_placeholder && nexpr->ref_count == 2)
+						expr_name_remove (nexpr);
+					expr_name_unref (nexpr);
+				}
+			}
+		g_ptr_array_free (container->v7.externnames, TRUE);
+		container->v7.externnames = NULL;
+	}
+	if (container->names != NULL) {
+		for (i = container->names->len; i-- > 0 ; )
+			if (g_ptr_array_index (container->names, i) != NULL) {
+				GnmNamedExpr *nexpr = g_ptr_array_index (container->names, i);
+				if (nexpr != NULL) {
+					/* NAME placeholders need removal, EXTERNNAME placeholders
+					 * will no be active */
+					if (nexpr->active && nexpr->is_placeholder && nexpr->ref_count == 2)
+						expr_name_remove (nexpr);
+					expr_name_unref (nexpr);
+				}
+			}
+		g_ptr_array_free (container->names, TRUE);
+		container->names = NULL;
+	}
 }
 
 void
@@ -69,10 +115,9 @@ ms_container_get_blip (MSContainer *container, int blip_id)
 	g_return_val_if_fail (container != NULL, NULL);
 	g_return_val_if_fail (blip_id >= 0, NULL);
 
-	if (container->parent_container != NULL &&
+	if (container->parent != NULL &&
 	    (container->blips == NULL || container->blips->len == 0))
-		    return ms_container_get_blip (container->parent_container,
-						  blip_id);
+		    return ms_container_get_blip (container->parent, blip_id);
 
 	g_return_val_if_fail (blip_id < (int)container->blips->len, NULL);
 
@@ -92,7 +137,22 @@ ms_container_set_blips (MSContainer *container, GPtrArray *blips)
 void
 ms_container_add_obj (MSContainer *container, MSObj *obj)
 {
-	container->obj_queue = g_list_prepend (container->obj_queue, obj);
+	container->obj_queue = g_slist_prepend (container->obj_queue, obj);
+}
+
+MSObj *
+ms_container_get_obj (MSContainer *c, int obj_id)
+{
+	MSObj *obj;
+	GSList *ptr;
+	
+	for (ptr = c->obj_queue ; ptr != NULL ; ptr = ptr->next) {
+		obj = (MSObj *)ptr->data;
+		if (obj != NULL && obj->id == obj_id)
+			return obj;
+	}
+	g_warning ("did not find %d\n", obj_id);
+	return NULL;
 }
 
 /**
@@ -105,14 +165,18 @@ ms_container_add_obj (MSContainer *container, MSObj *obj)
 void
 ms_container_realize_objs (MSContainer *container)
 {
-	GList *l;
+	GSList *ptr;
+	MSObj *obj;
 
 	g_return_if_fail (container != NULL);
 	g_return_if_fail (container->vtbl != NULL);
 	g_return_if_fail (container->vtbl->realize_obj != NULL);
 
-	for (l = container->obj_queue; l != NULL; l = l->next)
-		(void) (*container->vtbl->realize_obj) (container, l->data);
+	for (ptr = container->obj_queue; ptr != NULL; ptr = ptr->next) {
+		obj = (MSObj *)ptr->data;
+		if (obj->gnum_obj != NULL)
+			(void) (*container->vtbl->realize_obj) (container, obj);
+	}
 }
 
 /**
@@ -124,7 +188,7 @@ ms_container_realize_objs (MSContainer *container)
  *
  * Attempts to parse the encoded expression in the context of the container.
  */
-ExprTree *
+GnmExpr const *
 ms_container_parse_expr (MSContainer *c, guint8 const *data, int length)
 {
 	g_return_val_if_fail (c != NULL, NULL);
@@ -148,15 +212,38 @@ ms_container_sheet (MSContainer const *c)
 {
 	g_return_val_if_fail (c != NULL, NULL);
 	g_return_val_if_fail (c->vtbl != NULL, NULL);
-	g_return_val_if_fail (c->vtbl->sheet != NULL, NULL);
+	if (c->vtbl->sheet == NULL)
+		return NULL;
 	return (*c->vtbl->sheet) (c);
 }
 
-StyleFormat *
-ms_container_get_fmt (MSContainer const *c, guint16 indx)
+GnmFormat *
+ms_container_get_fmt (MSContainer const *c, unsigned indx)
 {
-	g_return_val_if_fail (c != NULL, NULL);
-	g_return_val_if_fail (c->vtbl != NULL, NULL);
-	g_return_val_if_fail (c->vtbl->get_fmt != NULL, NULL);
+	for ( ; TRUE ; c = c->parent) {
+		g_return_val_if_fail (c != NULL, NULL);
+		g_return_val_if_fail (c->vtbl != NULL, NULL);
+		if (c->vtbl->get_fmt != NULL)
+			break;
+	}
 	return (*c->vtbl->get_fmt) (c, indx);
 }
+
+/**
+ * ms_container_get_markup :
+ * @c : #MSContainer
+ * @indx :
+ *
+ * Return a #PangoAttrList the caller should not modify or free the list.
+ **/
+PangoAttrList *
+ms_container_get_markup (MSContainer const *c, unsigned indx)
+{
+	for ( ; TRUE ; c = c->parent) {
+		g_return_val_if_fail (c != NULL, NULL);
+		g_return_val_if_fail (c->vtbl != NULL, NULL);
+		if (c->vtbl->get_markup != NULL)
+			break;
+	}
+	return (*c->vtbl->get_markup) (c, indx);
+}
