@@ -49,8 +49,7 @@
 #endif
 
 /* A storage accumulator for common state information */
-typedef struct
-{
+typedef struct {
 	MSContainer	*container;
 	BiffQuery	*q;
 
@@ -61,8 +60,7 @@ typedef struct
 	gint32 end_offset;	/* 1st byte past end of current segment */
 } MSEscherState;
 
-typedef struct _MSEscherHeader
-{
+typedef struct _MSEscherHeader {
 	/* Read from the data stream */
 	guint	ver;
 	guint	instance;
@@ -149,7 +147,7 @@ ms_escher_blip_free (MSEscherBlip *blip)
 static guint8 const *
 ms_escher_get_data (MSEscherState *state,
 		    gint offset,	/* bytes from logical start of the stream */
-		    gint num_bytes,	/* how many bytes we want, NOT incl prefix */
+		    gint num_bytes,	/*how many bytes we want, NOT incl prefix */
 		    gboolean * needs_free)
 {
 	BiffQuery *q = state->q;
@@ -237,12 +235,12 @@ ms_escher_get_data (MSEscherState *state,
 
 static gboolean
 ms_escher_read_container (MSEscherState *state, MSEscherHeader *container,
-			  gint offset);
+			  gint prefix, gboolean return_attrs_in_container);
 
 /****************************************************************************/
 
 static gboolean
-ms_escher_read_CLSID (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_CLSID (MSEscherState *state, MSEscherHeader *h)
 {
 	/* Holds a 'Class ID Record' ID record which is only included in the
 	 * 'clipboard format'.  It contains an OLE CLSID record from the source
@@ -254,7 +252,7 @@ ms_escher_read_CLSID (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_ColorMRU (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_ColorMRU (MSEscherState *state, MSEscherHeader *h)
 {
 	d (3 , {
 		guint const num_Colours = h->instance;
@@ -268,13 +266,13 @@ ms_escher_read_ColorMRU (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_SplitMenuColors (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_SplitMenuColors (MSEscherState *state, MSEscherHeader *h)
 {
 	gboolean needs_free;
 	guint8 const * data;
 
 	g_return_val_if_fail (h->instance == 4, TRUE);
-	g_return_val_if_fail (h->len == 24, TRUE); /* header + 4*4 */
+	g_return_val_if_fail (h->len == 24, TRUE); /*header + 4*4 */
 
 	if ((data = ms_escher_get_data (state, h->offset + COMMON_HEADER_LEN,
 					16, &needs_free))) {
@@ -291,9 +289,9 @@ ms_escher_read_SplitMenuColors (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_BStoreContainer (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_BStoreContainer (MSEscherState *state, MSEscherHeader *h)
 {
-	return ms_escher_read_container (state, h, 0);
+	return ms_escher_read_container (state, h, 0, FALSE);
 }
 
 static gchar const *
@@ -311,7 +309,7 @@ bliptype_name (int const type)
 }
 
 static gboolean
-ms_escher_read_BSE (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_BSE (MSEscherState *state, MSEscherHeader *h)
 {
 	/* read the header */
 	gboolean needs_free;
@@ -357,7 +355,7 @@ ms_escher_read_BSE (MSEscherState * state, MSEscherHeader * h)
 
 	/* Ignore empties */
 	if (h->len > 36 + COMMON_HEADER_LEN)
-		return ms_escher_read_container (state, h, 36);
+		return ms_escher_read_container (state, h, 36, FALSE);
 
 	/* Store a blank */
 	ms_container_add_blip (state->container, NULL);
@@ -365,7 +363,7 @@ ms_escher_read_BSE (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_Blip (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_Blip (MSEscherState *state, MSEscherHeader *h)
 {
 	int offset = COMMON_HEADER_LEN + 16;
 	guint32 inst = h->instance;
@@ -455,9 +453,9 @@ ms_escher_read_Blip (MSEscherState * state, MSEscherHeader * h)
 			type = "dib";
 		offset++;
 		data = ms_escher_get_data (state, h->offset + offset,
-			h->len - offset - COMMON_HEADER_LEN, &needs_free);
+			h->len - offset, &needs_free);
 		blip = ms_escher_blip_new ((guint8 *)data,
-			h->len - offset - COMMON_HEADER_LEN, type, !needs_free);
+			h->len - offset, type, !needs_free);
 	} else {
 		failure = TRUE;
 		g_warning ("Don't know what to do with this image %x;", inst);
@@ -469,25 +467,25 @@ ms_escher_read_Blip (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_RegroupItems (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_RegroupItems (MSEscherState *state, MSEscherHeader *h)
 {
 	return FALSE;
 }
 
 static gboolean
-ms_escher_read_ColorScheme (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_ColorScheme (MSEscherState *state, MSEscherHeader *h)
 {
 	return FALSE;
 }
 
 static gboolean
-ms_escher_read_SpContainer (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_SpContainer (MSEscherState *state, MSEscherHeader *h)
 {
-	return ms_escher_read_container (state, h, 0);
+	return ms_escher_read_container (state, h, 0, FALSE);
 }
 
 static gboolean
-ms_escher_read_Spgr (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_Spgr (MSEscherState *state, MSEscherHeader *h)
 {
 	static char const * const shape_names[] = {
 		/* 0 */ "Not a primitive",
@@ -635,7 +633,7 @@ ms_escher_read_Spgr (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_Sp (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_Sp (MSEscherState *state, MSEscherHeader *h)
 {
 	gboolean needs_free;
 	guint8 const *data = ms_escher_get_data (state,
@@ -674,20 +672,51 @@ ms_escher_read_Sp (MSEscherState * state, MSEscherHeader * h)
 }
 
 static gboolean
-ms_escher_read_Textbox (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_Textbox (MSEscherState *state, MSEscherHeader *h)
 {
 	return FALSE;
 }
 
 static gboolean
-ms_escher_read_Anchor (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_Anchor (MSEscherState *state, MSEscherHeader *h)
 {
+	/* only needed for clipboard info, like child anchor with dim 100,000 */
 	return FALSE;
 }
 
 static gboolean
-ms_escher_read_ChildAnchor (MSEscherState * state, MSEscherHeader * h)
+ms_escher_read_ChildAnchor (MSEscherState *state, MSEscherHeader *h)
 {
+	gboolean needs_free;
+	int len = h->len - COMMON_HEADER_LEN;
+	guint8 const *data = ms_escher_get_data (state,
+		h->offset + COMMON_HEADER_LEN, len, &needs_free);
+
+#if 0
+	0 | 40  0  0  0 23  0  0  0	bd  0  0  0 44  0  0  0
+	0 | bd  0  0  0 44  0  0  0	3a  1  0  0 65  0  0  0
+	0 | 3a  1  0  0 66  0  0  0	b7  1  0  0 87  0  0  0
+
+	64	step 125
+	189	step 125
+	314	step 125
+	439
+
+	0 | 40  0  0  0 23  0  0  0	80  0  0  0 64  0  0  0
+	0 | 81  0  0  0 64  0  0  0	c1  0  0  0 a5  0  0  0
+	0 | c1  0  0  0 a6  0  0  0	 1  1  0  0 e7  0  0  0
+
+	64 in steps of 64
+
+	0 |  1  0  0  0 32  0  0  0 40  0  0  0 66  0  0  0 | ....2...@...f...
+	0 | 41  0  0  0 66  0  0  0 80  0  0  0 9a  0  0  0 | A...f...........
+	0 | 80  0  0  0 99  0  0  0 bf  0  0  0 cd  0  0  0 | ................
+
+	gsf_mem_dump (data, len);
+#endif
+
+	if (needs_free)
+		g_free ((guint8 *)data);
 	return FALSE;
 }
 
@@ -706,13 +735,15 @@ ms_escher_read_ClientAnchor (MSEscherState *state, MSEscherHeader *h)
 
 	data = ms_escher_get_data (state, h->offset + COMMON_HEADER_LEN,
 		MS_ANCHOR_SIZE, &needs_free);
+#if 0
+	gsf_mem_dump (data, MS_ANCHOR_SIZE);
+#endif
 	if (data) {
 		guint8 *anchor = g_malloc (MS_ANCHOR_SIZE);
 		memcpy (anchor, data, MS_ANCHOR_SIZE);
 
 		ms_escher_header_add_attr (h,
-			ms_obj_attr_new_ptr (MS_OBJ_ATTR_ANCHOR,
-						anchor));
+			ms_obj_attr_new_ptr (MS_OBJ_ATTR_ANCHOR, anchor));
 
 		if (needs_free)
 			g_free ((guint8 *)data);
@@ -1093,7 +1124,7 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 		guint const pid = tmp & 0x3fff;
 		gboolean const is_blip = (tmp & 0x4000) != 0;
 		gboolean const is_complex = (tmp & 0x8000) != 0;
-		guint32 const val = GSF_LE_GET_GUINT32(fopte+2);
+		guint32 val = GSF_LE_GET_GUINT32 (fopte+2);
 		MSObjAttrID id = MS_OBJ_ATTR_NONE;
 
 		/* container is sorted by pid. Use this as sanity test */
@@ -1355,9 +1386,13 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 		/* 0 :  */
 		case 394 : name = "long fillHeight"; break;
 		/* 0 : Fade angle - degrees in 16.16 */
-		case 395 : name = "long fillAngle"; break;
+		case 395 : id = MS_OBJ_ATTR_FILL_ANGLE;
+			   name = "long fillAngle";
+			   break;
 		/* 0 : Linear shaded fill focus percent */
-		case 396 : name = "long fillFocus"; break;
+		case 396 : id = MS_OBJ_ATTR_FILL_FOCUS;
+			   name = "long fillFocus";
+			   break;
 		/* 0 : Fraction 16.16 */
 		case 397 : name = "long fillToLeft"; break;
 		/* 0 : Fraction 16.16 */
@@ -1379,7 +1414,9 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 		/* measure_Default :  */
 		case 405 : name = "LengthMeasure fillDztype"; break;
 		/* 0 : Special shades */
-		case 406 : name = "long fillShadePreset"; break;
+		case 406 : id = MS_OBJ_ATTR_FILL_PRESET;
+			   name = "long fillShadePreset";
+			   break;
 		/* NULL : a preset array of colors */
 		case 407 : name = "IMsoArray fillShadeColors"; break;
 		/* 0 :  */
@@ -1391,7 +1428,9 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 		/* 0 :  */
 		case 411 : name = "long fillShapeOriginY"; break;
 		/* shade_Default : Type of shading, if a shaded (gradient) fill. */
-		case 412 : name = "ShadeType fillShadeType"; break;
+		case 412 : id = MS_OBJ_ATTR_FILL_SHADE_TYPE;
+			   name = "ShadeType fillShadeType";
+			   break;
 		/* TRUE : Is shape filled? */
 		case 443 : name = "bool fFilled"; break;
 		/* TRUE : Should we hit test fill?  */
@@ -1406,17 +1445,20 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 			/* NOTE : This test is somewhat questionable.
 			 * The docs say this is a bool but I have seen
 			 * 0x110000	not filled
+			 * 0x100000 	not filled
 			 * 0x110010	filled
 			 * 0x010000	filled
 			 */
-			if (val & 0x10)
-				id = MS_OBJ_ATTR_FILLED;
+			if (val != 0x110010 && val != 0x010000)
+				id = MS_OBJ_ATTR_UNFILLED;
 			name = "bool fNoFillHitTest";
 			break;
 
 	/* LineStyle */
 		/* black : Color of line */
-		case 448 : name = "Colour lineColor"; break;
+		case 448 : id = MS_OBJ_ATTR_OUTLINE_COLOR;
+			   name = "Colour lineColor";
+			   break;
 		/* 1<<16 : Not implemented */
 		case 449 : name = "long lineOpacity"; break;
 		/* white : Background color */
@@ -1476,7 +1518,12 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 		/* TRUE : Register pattern on shape */
 		case 510 : name = "bool lineFillShape"; break;
 		/* FALSE : Draw a dashed line if no line */
-		case 511 : name = "bool fNoLineDrawDash"; break;
+		case 511 : name = "bool fNoLineDrawDash";
+			   /* 0 == no line
+			    * 0x80008 == line */
+			if (val == 0)
+				id = MS_OBJ_ATTR_OUTLINE_STYLE;
+			break;
 
 	/* ShadowStyle */
 		/* Offset : Type of effect */
@@ -1773,17 +1820,17 @@ ms_escher_read_OPT (MSEscherState *state, MSEscherHeader *h)
 static gboolean
 ms_escher_read_SpgrContainer (MSEscherState *state, MSEscherHeader *h)
 {
-	return ms_escher_read_container (state, h, 0);
+	return ms_escher_read_container (state, h, 0, FALSE);
 }
 static gboolean
 ms_escher_read_DgContainer (MSEscherState *state, MSEscherHeader *h)
 {
-	return ms_escher_read_container (state, h, 0);
+	return ms_escher_read_container (state, h, 0, FALSE);
 }
 static gboolean
 ms_escher_read_DggContainer (MSEscherState *state, MSEscherHeader *h)
 {
-	return ms_escher_read_container (state, h, 0);
+	return ms_escher_read_container (state, h, 0, FALSE);
 }
 static gboolean
 ms_escher_read_ClientTextbox (MSEscherState *state, MSEscherHeader *h)
@@ -1791,6 +1838,7 @@ ms_escher_read_ClientTextbox (MSEscherState *state, MSEscherHeader *h)
 	guint16 opcode;
 	int has_next_record;
 	char *text;
+	PangoAttrList *markup;
 
 	g_return_val_if_fail (h->len == COMMON_HEADER_LEN, TRUE);
 	g_return_val_if_fail (h->offset + h->len == state->end_offset, TRUE);
@@ -1802,9 +1850,14 @@ ms_escher_read_ClientTextbox (MSEscherState *state, MSEscherHeader *h)
 	has_next_record = ms_biff_query_next (state->q);
 	g_return_val_if_fail (has_next_record, TRUE);
 
-	text = ms_read_TXO (state->q);
+	text = ms_read_TXO (state->q, state->container, &markup);
 	ms_escher_header_add_attr (h,
 		ms_obj_attr_new_ptr (MS_OBJ_ATTR_TEXT, text));
+	if (markup != NULL) {
+		ms_escher_header_add_attr (h,
+			ms_obj_attr_new_markup (MS_OBJ_ATTR_MARKUP, markup));
+		pango_attr_list_unref (markup);
+	}
 	d (0, printf ("'%s';\n", text););
 	return FALSE;
 }
@@ -1836,10 +1889,12 @@ ms_escher_read_ClientData (MSEscherState *state, MSEscherHeader *h)
 
 static gboolean
 ms_escher_read_container (MSEscherState *state, MSEscherHeader *container,
-			  gint const prefix)
+			  gint prefix, gboolean return_attrs_in_container)
 {
 	MSEscherHeader h;
 
+	g_return_val_if_fail (container != NULL, TRUE);
+
 	ms_escher_header_init (&h);
 	h.container = container;
 
@@ -1943,25 +1998,30 @@ ms_escher_read_container (MSEscherState *state, MSEscherHeader *container,
 		h.offset += h.len;
 	} while (h.offset < (container->offset + container->len));
 
+	if (container->attrs == NULL && return_attrs_in_container) {
+		container->attrs = h.attrs;
+		h.release_attrs = FALSE;
+	}
 	ms_escher_header_release (&h);
 	return FALSE;
 }
 
 /*
  * ms_escher_parse:
- * @q:     Biff context.
- * @wb:    required workbook argument
- * @sheet: optional sheet argument
+ * @q:
+ * @container:    required workbook argument
+ * @return_attrs: Should we steal our childrens attributes and return them
  *
- *   This function parses an escher stream, and stores relevant data in the
- * workbook.
+ * Parse an escher stream stores in a sequence of biff records
+ *
+ * Returns NULL or an MSObjAttrBag (callers frees) depending on @return_attrs
  */
 MSObjAttrBag *
-ms_escher_parse (BiffQuery *q, MSContainer *container)
+ms_escher_parse (BiffQuery *q, MSContainer *container, gboolean return_attrs)
 {
 	MSEscherState state;
 	MSEscherHeader fake_header;
-	MSObjAttrBag  *attrs;
+	MSObjAttrBag *res = NULL;
 	char const *drawing_record_name = "Unknown";
 
 	g_return_val_if_fail (q != NULL, NULL);
@@ -1990,14 +2050,16 @@ ms_escher_parse (BiffQuery *q, MSContainer *container)
 	fake_header.offset = 0;
 
 	d (0, printf ("{  /* Escher '%s'*/\n", drawing_record_name););
-	ms_escher_read_container (&state, &fake_header, -COMMON_HEADER_LEN);
+	ms_escher_read_container (&state,
+		&fake_header, -COMMON_HEADER_LEN, return_attrs);
 	d (0, printf ("}; /* Escher '%s'*/\n", drawing_record_name););
 
-	attrs = fake_header.attrs;
+	if (return_attrs) {
+		res = fake_header.attrs;
 	fake_header.release_attrs = FALSE;
+	}
 	ms_escher_header_release (&fake_header);
-
-	return attrs;
+	return res;
 }
 
 /****************************************************************************/
