@@ -12,15 +12,15 @@
 
 #define EXCEL_TYPE_GB_INTERIOR            (excel_gb_interior_get_type ())
 #define EXCEL_GB_INTERIOR(obj)            (GTK_CHECK_CAST ((obj), EXCEL_TYPE_GB_INTERIOR, ExcelGBInterior))
-#define EXCEL_GB_INTERIOR_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), EXCEL_TYPE_GB_INTERIOR, ExcelGBInteriorClass))
-#define EXCEL_IS_GB_INTERIOR(obj)         (GTK_CHECK_TYPE ((obj), EXCEL_TYPE_GB_INTERIOR))
-#define EXCEL_IS_GB_INTERIOR_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), EXCEL_TYPE_GB_INTERIOR))
+#define EXCEL_GB_INTERIOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), EXCEL_TYPE_GB_INTERIOR, ExcelGBInteriorClass))
+#define EXCEL_IS_GB_INTERIOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EXCEL_TYPE_GB_INTERIOR))
+#define EXCEL_IS_GB_INTERIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EXCEL_TYPE_GB_INTERIOR))
 
 typedef struct {
 	GBRunObject object;
 
 	Sheet      *sheet;
-	Range       range;
+	GnmRange       range;
 } ExcelGBInterior;
 
 typedef struct {
@@ -28,6 +28,6 @@ typedef struct {
 } ExcelGBInteriorClass;
 
 GtkType          excel_gb_interior_get_type (void);
-ExcelGBInterior *excel_gb_interior_new      (Sheet *sheet, Range range);
+ExcelGBInterior *excel_gb_interior_new      (Sheet *sheet, GnmRange range);
 
 #endif /* EXCEL_GB_INTERIOR_H */
