@@ -38,6 +38,7 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
+#include <gnumeric-gconf.h>
 #include "latex.h"
 #include <plugin-util.h>
 #include <io-context.h>
@@ -50,7 +51,7 @@
 #include <style-color.h>
 #include <font.h>
 #include <cell.h>
-#include <formats.h>
+#include <format.h>
 #include <style-border.h>
 #include <sheet-style.h>
 #include <parse-util.h>
@@ -59,6 +60,7 @@
 
 #include <locale.h>
 #include <gsf/gsf-output.h>
+#include <string.h>
 
 typedef enum {
 	LATEX_NO_BORDER = 0,
@@ -130,9 +132,8 @@ static latex_border_connectors_t const conn_styles[LATEX_MAX_BORDER]
 	  {{":b:",""}, { ":b:",""}, { ":",":"}}}}
 };
 
-
 /**
- * latex_fputs :
+ * latex_fputs_utf :
  *
  * @p :      a pointer to a char, start of the string to be processed.
  * @output : output stream where the processed characters are written.
@@ -141,37 +142,38 @@ static latex_border_connectors_t const conn_styles[LATEX_MAX_BORDER]
  * from Rasca's code to have most common first.
  */
 static void
-latex_fputs (char const *p, GsfOutput *output)
+latex_fputs_utf (char const *p, GsfOutput *output)
 {
-	for (; *p; p++) {
-		switch (*p) {
-
+	for (; *p; p = g_utf8_next_char (p)) {
+		switch (g_utf8_get_char (p)) {
+			
 			/* These are the classic TeX symbols $ & % # _ { } (see Lamport, p.15) */
-			case '$': case '&': case '%': case '#':
-			case '_': case '{': case '}':
-				gsf_output_printf (output, "\\%c", *p);
-				break;
+		case '$': case '&': case '%': case '#':
+		case '_': case '{': case '}':
+			gsf_output_printf (output, "\\%c", *p);
+			break;
 			/* These are the other special characters ~ ^ \ (see Lamport, p.15) */
-			case '^': case '~':
-				gsf_output_printf (output, "\\%c{ }", *p);
-				break;
-			case '\\':
-				gsf_output_puts (output, "$\\backslash$");
-				break;
+		case '^': case '~':
+			gsf_output_printf (output, "\\%c{ }", *p);
+			break;
+		case '\\':
+			gsf_output_puts (output, "$\\backslash$");
+			break;
 			/* Are these available only in LaTeX through mathmode? */
-			case '>': case '<':
-				gsf_output_printf (output, "$%c$", *p);
-				break;
-
-			default:
-				gsf_output_write (output, 1, p);
-				break;
+		case '>': case '<':
+			gsf_output_printf (output, "$%c$", *p);
+			break;
+			
+		default:
+			gsf_output_write (output, 
+					  (g_utf8_next_char (p)) - p, p);
+			break;
 		}
 	}
 }
 
 /**
- * latex_math_fputs :
+ * latex_math_fputs_utf :
  *
  * @p :     a pointer to a char, start of the string to be processed.
  * @output: output stream where the processed characters are written.
@@ -181,9 +183,117 @@ latex_fputs (char const *p, GsfOutput *output)
  * We assume that htis will be set in Mathematics mode.
  */
 static void
-latex_math_fputs (char const *p, GsfOutput *output)
+latex_math_fputs_utf (char const *p, GsfOutput *output)
 {
-	for (; *p; p++) {
+	for (; *p; p = g_utf8_next_char (p)) {
+		switch (g_utf8_get_char (p)) {
+
+			/* These are the classic TeX symbols $ & % # (see Lamport, p.15) */
+			case '$': case '&': case '%': case '#':
+				gsf_output_printf (output, "\\%c", *p);
+				break;
+			/* These are the other special characters ~ (see Lamport, p.15) */
+			case '~':
+				gsf_output_printf (output, "\\%c{ }", *p);
+				break;
+			case '\\':
+				gsf_output_puts (output, "\\backslash");
+				break;
+
+			default:
+				gsf_output_write (output, 
+						  (g_utf8_next_char (p)) - p, p);
+				break;
+		}
+	}
+}
+
+/**
+ * latex_fputs_latin :
+ *
+ * @p :      a pointer to a char, start of the string to be processed.
+ * @output : output stream where the processed characters are written.
+ *
+ * This escapes any special LaTeX characters from the LaTeX engine. Re-ordered
+ * from Rasca's code to have most common first.
+ */
+static void
+latex_fputs_latin (char const *text, GsfOutput *output)
+{
+	char * encoded_text = NULL;
+	char * p;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError * error = NULL;
+
+	encoded_text = g_convert_with_fallback
+		(text, strlen (text),
+		 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+		 &bytes_read, &bytes_written, &error);
+	if (error != NULL)
+	{
+		g_warning ("UTF-8 to Latin1 conversion failed for:\n%s", text);
+		g_error_free (error);
+	}
+
+	for (p = encoded_text; *p; p++) {
+		switch (*p) {
+			
+			/* These are the classic TeX symbols $ & % # _ { } (see Lamport, p.15) */
+		case '$': case '&': case '%': case '#':
+		case '_': case '{': case '}':
+			gsf_output_printf (output, "\\%c", *p);
+			break;
+			/* These are the other special characters ~ ^ \ (see Lamport, p.15) */
+		case '^': case '~':
+			gsf_output_printf (output, "\\%c{ }", *p);
+			break;
+		case '\\':
+			gsf_output_puts (output, "$\\backslash$");
+			break;
+			/* Are these available only in LaTeX through mathmode? */
+		case '>': case '<': case '':
+			gsf_output_printf (output, "$%c$", *p);
+			break;
+			
+		default:
+			gsf_output_write (output, 1, p);
+			break;
+		}
+	}
+	g_free (encoded_text);
+}
+
+/**
+ * latex_math_fputs_latin :
+ *
+ * @p :     a pointer to a char, start of the string to be processed.
+ * @output: output stream where the processed characters are written.
+ *
+ * This escapes any special LaTeX characters from the LaTeX engine.
+ * 
+ * We assume that htis will be set in Mathematics mode.
+ */
+static void
+latex_math_fputs_latin (char const *text, GsfOutput *output)
+{
+	char * encoded_text = NULL;
+	char * p;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError * error = NULL;
+
+	encoded_text = g_convert_with_fallback
+		(text, strlen (text),
+		 "ISO-8859-1", "UTF-8", (gchar *)"?", 
+		 &bytes_read, &bytes_written, &error);
+	if (error != NULL)
+	{
+		g_warning ("UTF-8 to Latin1 conversion failed for:\n%s", text);
+		g_error_free (error);
+	}
+
+	for (p = encoded_text; *p; p++) {
 		switch (*p) {
 
 			/* These are the classic TeX symbols $ & % # (see Lamport, p.15) */
@@ -203,8 +313,26 @@ latex_math_fputs (char const *p, GsfOutput *output)
 				break;
 		}
 	}
+	g_free (encoded_text);
 }
 
+static void
+latex_fputs (char const *text, GsfOutput *output)
+{
+	if (gnm_app_prefs->latex_use_utf8)
+		latex_fputs_utf (text, output);
+	else
+		latex_fputs_latin (text, output);
+}
+
+static void
+latex_math_fputs (char const *text, GsfOutput *output)
+{
+	if (gnm_app_prefs->latex_use_utf8)
+		latex_math_fputs_utf (text, output);
+	else
+		latex_math_fputs_latin (text, output);
+}
 
 /**
  * latex2e_write_file_header:
@@ -230,12 +358,24 @@ latex2e_write_file_header(GsfOutput *output)
 "%%  To include the file in another, the following two lines must be %%\n"
 "%%  in the including file:                                          %%\n"
 "%%        \\def\\inputGnumericTable{}                                 %%\n"
-"%%  at the begining of the file and:                                %%\n"
+"%%  at the beginning of the file and:                               %%\n"
 "%%        \\input{name-of-this-file.tex}                             %%\n"
 "%%  where the table is to be placed. Note also that the including   %%\n"
 "%%  file must use the following packages for the table to be        %%\n"
 "%%  rendered correctly:                                             %%\n"
+);
+
+	if (gnm_app_prefs->latex_use_utf8)
+		gsf_output_puts (output,
+"%%    \\usepackage{ucs}                                            %%\n"
+"%%    \\usepackage[utf8]{inputenc}                                 %%\n"
+			);
+	else
+		gsf_output_puts (output,
 "%%    \\usepackage[latin1]{inputenc}                                 %%\n"
+			);
+
+	gsf_output_puts (output,
 "%%    \\usepackage{color}                                            %%\n"
 "%%    \\usepackage{array}                                            %%\n"
 "%%    \\usepackage{longtable}                                        %%\n"
@@ -276,14 +416,28 @@ latex2e_write_file_header(GsfOutput *output)
 "	\\documentclass[12pt%\n"
 "	                  %,landscape%\n"
 "                    ]{report}\n"
-"	\\usepackage[latin1]{inputenc}\n"
+		);
+
+
+	if (gnm_app_prefs->latex_use_utf8)
+		gsf_output_puts (output,
+"       \\usepackage{ucs}\n"
+"       \\usepackage[utf8]{inputenc}\n"
+			);
+	else
+		gsf_output_puts (output,
+"       \\usepackage[latin1]{inputenc}\n"
+			);
+
+	gsf_output_puts (output,
+"	\\usepackage{fullpage}\n"
 "	\\usepackage{color}\n"
-"        \\usepackage{array}\n"
+"       \\usepackage{array}\n"
 "	\\usepackage{longtable}\n"
-"        \\usepackage{calc}\n"
-"        \\usepackage{multirow}\n"
-"        \\usepackage{hhline}\n"
-"        \\usepackage{ifthen}\n"
+"       \\usepackage{calc}\n"
+"       \\usepackage{multirow}\n"
+"       \\usepackage{hhline}\n"
+"       \\usepackage{ifthen}\n"
 "\n"
 "	\\begin{document}\n"
 "\n"
@@ -412,8 +566,8 @@ latex2e_write_table_header(GsfOutput *output, int num_cols)
 static StyleBorderType
 latex2e_find_vline (int col, int row, Sheet *sheet, MStyleElementType which_border)
 {
-	StyleBorder	   *border;
-	MStyle             *mstyle;
+	GnmBorder	   *border;
+	GnmStyle             *mstyle;
 
 	if (col < 0 || row < 0)
 		return STYLE_BORDER_NONE;
@@ -476,7 +630,7 @@ static void
 latex2e_write_blank_cell (GsfOutput *output, gint col, gint row, gint index,
 			  StyleBorderType *borders, Sheet *sheet)
 {
-	CellPos pos;
+	GnmCellPos pos;
 	StyleBorderType left_border = STYLE_BORDER_NONE;
 	StyleBorderType right_border = STYLE_BORDER_NONE;
 
@@ -525,21 +679,20 @@ latex2e_write_blank_cell (GsfOutput *output, gint col, gint row, gint index,
  * makes it much more difficult to change column widths later on.
  */
 static void
-latex2e_write_multicolumn_cell (GsfOutput *output, Cell *cell, int num_merged_cols,
+latex2e_write_multicolumn_cell (GsfOutput *output, GnmCell *cell, int num_merged_cols,
 				int num_merged_rows,  gint index,
 				StyleBorderType *borders, Sheet *sheet)
 {
 	char * rendered_string;
 	gushort r,g,b;
 	gboolean wrap = FALSE;
-	FormatCharacteristics cell_format_characteristic;
 	FormatFamily cell_format_family;
 	int merge_width = 0;
 	StyleBorderType left_border = STYLE_BORDER_NONE;
 	StyleBorderType right_border = STYLE_BORDER_NONE;
 
 	/* Print the cell according to its style. */
-	MStyle *mstyle = cell_get_mstyle (cell);
+	GnmStyle *mstyle = cell_get_mstyle (cell);
 	gboolean hidden = mstyle_get_content_hidden (mstyle);
 
 	g_return_if_fail (mstyle != NULL);
@@ -665,7 +818,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, Cell *cell, int num_merged_co
 			break;
 		}
 
-	if (!cell_is_blank (cell)) {
+	if (!cell_is_empty (cell)) {
                 /* Check the foreground (text) colour. */
 		const PangoColor *fore = cell_get_render_color (cell);
 		if (fore == NULL)
@@ -700,8 +853,7 @@ latex2e_write_multicolumn_cell (GsfOutput *output, Cell *cell, int num_merged_co
 			gsf_output_printf (output, "\\textit{");
 
 
-		cell_format_family = cell_format_classify (cell_get_format (cell),
-							   &cell_format_characteristic);
+		cell_format_family = cell_get_format (cell)->family;
 		if (cell_format_family == FMT_NUMBER || cell_format_family == FMT_CURRENCY ||
 		    cell_format_family == FMT_PERCENT || cell_format_family == FMT_FRACTION ||
 		    cell_format_family == FMT_SCIENCE){
@@ -774,10 +926,10 @@ static gboolean
 latex2e_find_hhlines (StyleBorderType *clines, int length, int col, int row,
 		      Sheet *sheet, MStyleElementType type)
 {
-	MStyle *mstyle;
-	StyleBorder	   *border;
- 	Range const *merge_range;
-	CellPos pos;
+	GnmStyle *mstyle;
+	GnmBorder	   *border;
+ 	GnmRange const *merge_range;
+	GnmCellPos pos;
 
 	mstyle = sheet_style_get (sheet, col, row);
 	border = mstyle_get_border (mstyle, type);
@@ -869,10 +1021,10 @@ void
 latex_file_save (GnmFileSaver const *fs, IOContext *io_context,
 		 WorkbookView const *wb_view, GsfOutput *output)
 {
-	Cell *cell;
+	GnmCell *cell;
 	Sheet *current_sheet;
-	Range total_range;
- 	Range const *merge_range;
+	GnmRange total_range;
+ 	GnmRange const *merge_range;
 	int row, col, num_cols, length;
 	int num_merged_cols, num_merged_rows;
 	StyleBorderType *clines, *this_clines;
@@ -1001,7 +1153,7 @@ latex_file_save (GnmFileSaver const *fs, IOContext *io_context,
 			/* covered by a span!                                    */
 			the_span = row_span_get (ri, col);
 			if (the_span != NULL) {
-				latex2e_write_multicolumn_cell(output, (Cell *)the_span->cell,
+				latex2e_write_multicolumn_cell(output, (GnmCell *)the_span->cell,
 							       the_span->right -
 							       col + 1, 1,
 							       col - total_range.start.col,
@@ -1012,7 +1164,7 @@ latex_file_save (GnmFileSaver const *fs, IOContext *io_context,
 
 
 			/* A blank cell has only a few options*/
-			if (cell_is_blank(cell)) {
+			if (cell_is_empty(cell)) {
 				latex2e_write_blank_cell(output, col, row,
 							col - total_range.start.col,
 							next_vert, current_sheet);
