@@ -133,7 +133,7 @@ sc_parse_coord (char const **strdata, int *col, int *row)
 static gboolean
 sc_parse_label (Sheet *sheet, char const *cmd, char const *str, int col, int row)
 {
-	Cell *cell;
+	GnmCell *cell;
 	char *s = NULL, *tmpout;
 	char const *tmpstr;
 	gboolean result = FALSE;
@@ -179,7 +179,7 @@ sc_parse_label (Sheet *sheet, char const *cmd, char const *str, int col, int row
 		cmdtype = LABEL;
 
 	if (cmdtype == LEFTSTRING || cmdtype == RIGHTSTRING) {
-		MStyle *mstyle;
+		GnmStyle *mstyle;
 
 		mstyle = cell_get_mstyle (cell);
 		if (!mstyle)
@@ -207,7 +207,7 @@ sc_parse_cell_name_list (Sheet *sheet, char const *cell_name_str,
 {
         char     *buf;
 	GSList   *cells = NULL;
-	Cell     *cell;
+	GnmCell     *cell;
 	GnmCellPos   pos;
 	int      i, n;
 
@@ -245,7 +245,7 @@ sc_parse_cell_name_list (Sheet *sheet, char const *cell_name_str,
 
 
 static char const *
-sc_rangeref_parse (GnmRangeRef *res, char const *start, ParsePos const *pp)
+sc_rangeref_parse (GnmRangeRef *res, char const *start, GnmParsePos const *pp)
 {
 	/* This is a hack.  We still cannot handle sc's row 0.  */
 	char const *end = rangeref_parse (res, start, pp);
@@ -260,8 +260,8 @@ static gboolean
 sc_parse_let (Sheet *sheet, char const *cmd, char const *str, int col, int row)
 {
 	GnmExpr const *tree;
-	Cell *cell;
-	ParsePos pos;
+	GnmCell *cell;
+	GnmParsePos pos;
 	GnmValue const *v;
 
 	g_return_val_if_fail (sheet, FALSE);
@@ -290,7 +290,7 @@ sc_parse_let (Sheet *sheet, char const *cmd, char const *str, int col, int row)
 
 	v = gnm_expr_get_constant (tree);
 	if (v && VALUE_IS_NUMBER (v)) {
-		cell_set_value (cell, value_duplicate (v));
+		cell_set_value (cell, value_dup (v));
 	} else {
 		cell_set_expr (cell, tree);
 	}
