@@ -33,6 +33,7 @@
 #include "sheet-merge.h"
 #include "cell.h"
 #include "cellspan.h"
+#include "rendered-value.h"
 
 void
 colrow_compute_pixels_from_pts (ColRowInfo *cri,
@@ -41,7 +42,7 @@ colrow_compute_pixels_from_pts (ColRowInfo *cri,
 	int const margin = cri->margin_a + cri->margin_b;
 	double const scale =
 		sheet->last_zoom_factor_used *
-		application_display_dpi_get (horizontal) / 72.;
+		gnm_app_display_dpi_get (horizontal) / 72.;
 
 	cri->size_pixels = (int)(cri->size_pts * scale + 0.5);
 	if (cri->size_pixels <= margin)
@@ -54,7 +55,7 @@ colrow_compute_pts_from_pixels (ColRowInfo *cri,
 {
 	double const scale =
 		sheet->last_zoom_factor_used *
-		application_display_dpi_get (horizontal) / 72.;
+		gnm_app_display_dpi_get (horizontal) / 72.;
 
 	cri->size_pts = cri->size_pixels / scale;
 #if 0
@@ -71,6 +72,23 @@ colrow_is_default (ColRowInfo const *cri)
 	return cri->pos < 0;
 }
 
+/**
+ * colrow_is_empty :
+ * @colrow : #ColRowInfo
+ *
+ * TRUE if there is no information in col/row @cri.
+ **/
+gboolean
+colrow_is_empty (ColRowInfo const *cri)
+{
+	if (cri == NULL)
+		return TRUE;
+	return   cri->is_default &&
+		 cri->outline_level == 0 &&
+		!cri->is_collapsed &&
+		!cri->hard_size;
+}
+
 /**
  * colrow_equal :
  * @a : ColRowInfo #1
@@ -393,6 +411,17 @@ cb_set_colrow_size (ColRowInfo *info, void *userdata)
 	return FALSE;
 }
 
+static GnmValue *
+cb_clear_variable_width_content (Sheet *sheet, int col, int row, GnmCell *cell)
+{
+	if (cell->rendered_value != NULL &&
+	    cell->rendered_value->variable_width) {
+		rendered_value_destroy (cell->rendered_value);
+		cell->rendered_value = NULL;
+	}
+	return NULL;
+}
+
 ColRowStateGroup *
 colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 		  ColRowIndexList *src, int new_size)
@@ -441,6 +470,12 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 			return g_slist_prepend (res, g_slist_append (NULL, rles));
 		}
 
+		/* force a re-render of cells with expanding formats */
+		if (is_cols)
+			sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
+				index->first, 0, index->last, SHEET_MAX_ROWS-1,
+				(CellIterFunc) &cb_clear_variable_width_content, 0);
+
 		for (i = index->first ; i <= index->last ; ++i) {
 			int tmp = new_size;
 			gboolean set_default = (tmp == 0);
@@ -561,6 +596,11 @@ colrow_restore_state_group (Sheet *sheet, gboolean is_cols,
 		}
 
 		colrow_set_states (sheet, is_cols, index->first, ptr->data);
+		/* force a re-render of cells with expanding formats */
+		if (is_cols)
+			sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
+				index->first, 0, index->last, SHEET_MAX_ROWS-1,
+				(CellIterFunc) &cb_clear_variable_width_content, 0);
 		colrow_state_list_destroy (ptr->data);
 		selection = selection->prev;
 	}
