@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * complete.c: Our auto completion engine.  This is an abstract class
  * that must be derived to implement its actual functionality.
@@ -16,20 +17,19 @@
  *    notification function that was provided to Complete.
  *
  *
- * (C) 2000 Helix Code, Inc.
+ * (C) 2000-2001 Ximain Inc.
  */
-#include <config.h>
-#include <gtk/gtkmain.h>
+#include <gnumeric-config.h>
+#include "gnumeric.h"
 #include "complete.h"
-#include <gal/util/e-util.h>
 
+#include <gsf/gsf-impl-utils.h>
+#include <gtk/gtkmain.h>
 #include <stdio.h>
 #include <stdlib.h>
 
-#define PARENT_TYPE (gtk_object_get_type ())
-#define ACC(o) (COMPLETE_CLASS (GTK_OBJECT (o)->klass))
-
-static GtkObjectClass *parent_class;
+#define PARENT_TYPE (G_TYPE_OBJECT)
+#define ACC(o) (COMPLETE_CLASS (G_OBJECT_GET_CLASS (o)))
 
 void
 complete_construct (Complete *complete,
@@ -41,12 +41,13 @@ complete_construct (Complete *complete,
 }
 
 static void
-complete_destroy (GtkObject *object)
+complete_finalize (GObject *object)
 {
+	GObjectClass *parent;
 	Complete *complete = COMPLETE (object);
 
 	if (complete->idle_tag) {
-		gtk_idle_remove (complete->idle_tag);
+		g_source_remove (complete->idle_tag);
 		complete->idle_tag = 0;
 	}
 
@@ -55,8 +56,9 @@ complete_destroy (GtkObject *object)
 		complete->text = 0;
 	}
 
-	if (parent_class->destroy)
-		(parent_class->destroy) (object);
+	parent = g_type_class_peek (PARENT_TYPE);
+	if (parent != NULL && parent->finalize != NULL)
+		(parent->finalize) (object);
 }
 
 static gint
@@ -77,7 +79,7 @@ complete_idle (gpointer data)
 }
 
 void
-complete_start (Complete *complete, const char *text)
+complete_start (Complete *complete, char const *text)
 {
 	g_return_if_fail (complete != NULL);
 	g_return_if_fail (IS_COMPLETE (complete));
@@ -90,27 +92,26 @@ complete_start (Complete *complete, const char *text)
 	}
 
 	if (complete->idle_tag == 0)
-		complete->idle_tag = gtk_idle_add (complete_idle, complete);
+		complete->idle_tag = g_idle_add (complete_idle, complete);
 
 	if (ACC(complete)->start_over)
 		ACC(complete)->start_over (complete);
 }
 
 static gboolean
-default_search_iteration (Complete *complete)
+default_search_iteration (G_GNUC_UNUSED Complete *complete)
 {
 	return FALSE;
 }
 
 static void
-complete_class_init (GtkObjectClass *object_class)
+complete_class_init (GObjectClass *object_class)
 {
 	CompleteClass *complete_class = (CompleteClass *) object_class;
 
-	object_class->destroy = complete_destroy;
+	object_class->finalize = complete_finalize;
 	complete_class->search_iteration = default_search_iteration;
-
-	parent_class = gtk_type_class (PARENT_TYPE);
 }
 
-E_MAKE_TYPE(complete, "Complete", Complete, &complete_class_init, NULL, PARENT_TYPE);
+GSF_CLASS (Complete, complete,
+	   &complete_class_init, NULL, PARENT_TYPE);
