@@ -28,7 +28,6 @@
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-grid.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/utils/go-units.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <src/gnumeric-i18n.h>
@@ -37,24 +36,24 @@
 
 enum {
 	CHART_PROP_0,
-	CHART_PROP_PADDING_PTS,
 	CHART_PROP_CARDINALITY_VALID
 };
 
 static GType gog_chart_view_get_type (void);
 static GObjectClass *chart_parent_klass;
 
-static gpointer
-gog_chart_editor (GogObject *gobj, GogDataAllocator *dalloc, CommandContext *cc)
-{
-	return gog_style_editor	(gobj, cc, NULL, GOG_STYLE_OUTLINE | GOG_STYLE_FILL);
-}
-
 static void
-gog_chart_update (GogObject *chart)
+gog_chart_update (GogObject *obj)
 {
-	/* resets the counts */
-	(void) gog_chart_get_cardinality (GOG_CHART (chart));
+	GogChart *chart = GOG_CHART (obj);
+	unsigned full = chart->full_cardinality;
+	unsigned visible = chart->visible_cardinality;
+
+	gog_chart_get_cardinality (chart, NULL, NULL);
+
+	if (full != chart->full_cardinality ||
+	    visible != chart->visible_cardinality)
+		g_object_notify (G_OBJECT (chart), "cardinality-valid");
 }
 
 static void
@@ -69,31 +68,12 @@ gog_chart_finalize (GObject *obj)
 	(chart_parent_klass->finalize) (obj);
 }
 
-static void
-gog_chart_set_property (GObject *obj, guint param_id,
-			GValue const *value, GParamSpec *pspec)
-{
-	GogChart *chart = GOG_CHART (obj);
-	switch (param_id) {
-	case CHART_PROP_PADDING_PTS :
-		chart->padding_pts = g_value_get_double (value);
-		gog_object_emit_changed (GOG_OBJECT (obj), TRUE);
-		break;
-
-	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
-		 return; /* NOTE : RETURN */
-	}
-}
-
 static void
 gog_chart_get_property (GObject *obj, guint param_id,
 			GValue *value, GParamSpec *pspec)
 {
 	GogChart *chart = GOG_CHART (obj);
 	switch (param_id) {
-	case CHART_PROP_PADDING_PTS :
-		g_value_set_double (value, chart->padding_pts);
-		break;
 	case CHART_PROP_CARDINALITY_VALID:
 		g_value_set_boolean (value, chart->cardinality_valid);
 		break;
@@ -103,6 +83,21 @@ gog_chart_get_property (GObject *obj, guint param_id,
 	}
 }
 
+static void
+gog_chart_children_reordered (GogObject *obj)
+{
+	GSList *ptr, *accum = NULL;
+	GogChart *chart = GOG_CHART (obj);
+
+	for (ptr = obj->children; ptr != NULL ; ptr = ptr->next)
+		if (IS_GOG_PLOT (ptr->data))
+			accum = g_slist_prepend (accum, ptr->data);
+	g_slist_free (chart->plots);
+	chart->plots = g_slist_reverse (accum);
+
+	gog_chart_request_cardinality_update (chart);
+}
+
 static void
 role_plot_post_add (GogObject *parent, GogObject *plot)
 {
@@ -224,21 +219,16 @@ gog_chart_class_init (GogObjectClass *gog_klass)
 
 	chart_parent_klass = g_type_class_peek_parent (gog_klass);
 	gobject_klass->finalize = gog_chart_finalize;
-	gobject_klass->set_property = gog_chart_set_property;
 	gobject_klass->get_property = gog_chart_get_property;
 
-	g_object_class_install_property (gobject_klass, CHART_PROP_PADDING_PTS,
-		g_param_spec_double ("padding_pts", "Padding Pts",
-			"# of pts separating charts in the grid.",
-			0, G_MAXDOUBLE, 0, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, CHART_PROP_CARDINALITY_VALID,
 		g_param_spec_boolean ("cardinality-valid", "cardinality-valid",
 			"Is the charts cardinality currently vaid",
 			FALSE, G_PARAM_READABLE));
 
-	gog_klass->editor    = gog_chart_editor;
 	gog_klass->view_type = gog_chart_view_get_type ();
 	gog_klass->update    = gog_chart_update;
+	gog_klass->children_reordered = gog_chart_children_reordered;
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 }
 
@@ -249,7 +239,6 @@ gog_chart_init (GogChart *chart)
 	chart->y     = 0;
 	chart->cols  = 0;
 	chart->rows  = 0;
-	chart->padding_pts = GO_CM_TO_PT (.25);
 
 	/* start as true so that we can queue an update when it changes */
 	chart->cardinality_valid = TRUE;
@@ -258,7 +247,7 @@ gog_chart_init (GogChart *chart)
 
 GSF_CLASS (GogChart, gog_chart,
 	   gog_chart_class_init, gog_chart_init,
-	   GOG_STYLED_OBJECT_TYPE)
+	   GOG_OUTLINED_OBJECT_TYPE)
 
 /**
  * gog_chart_get_position :
@@ -315,20 +304,28 @@ gog_chart_set_position (GogChart *chart,
 	gog_object_emit_changed (GOG_OBJECT (chart), TRUE);
 }
 
-unsigned
-gog_chart_get_cardinality (GogChart *chart)
+void
+gog_chart_get_cardinality (GogChart *chart, unsigned *full, unsigned *visible)
 {
 	GSList *ptr;
+	unsigned tmp_full, tmp_visible;
 
-	g_return_val_if_fail (GOG_CHART (chart) != NULL, 0);
+	g_return_if_fail (GOG_CHART (chart) != NULL);
 
 	if (!chart->cardinality_valid) {
 		chart->cardinality_valid = TRUE;
-		chart->cardinality = 0;
-		for (ptr = chart->plots ; ptr != NULL ; ptr = ptr->next)
-			chart->cardinality += gog_plot_get_cardinality (ptr->data);
+		chart->full_cardinality = chart->visible_cardinality = 0;
+		for (ptr = chart->plots ; ptr != NULL ; ptr = ptr->next) {
+			gog_plot_get_cardinality (ptr->data, &tmp_full, &tmp_visible);
+			chart->full_cardinality += tmp_full;
+			chart->visible_cardinality += tmp_visible;
 	}
-	return chart->cardinality;
+	}
+
+	if (full != NULL)
+		*full = chart->full_cardinality;
+	if (visible != NULL)
+		*visible = chart->visible_cardinality;
 }
 
 void
@@ -338,13 +335,13 @@ gog_chart_request_cardinality_update (GogChart *chart)
 	
 	if (chart->cardinality_valid) {
 		chart->cardinality_valid = FALSE;
-		g_object_notify (G_OBJECT (chart), "cardinality-valid");
 		gog_object_request_update (GOG_OBJECT (chart));
 	}
 }
 
 void
-gog_chart_foreach_elem (GogChart *chart, GogEnumFunc handler, gpointer data)
+gog_chart_foreach_elem (GogChart *chart, gboolean only_visible,
+			GogEnumFunc handler, gpointer data)
 {
 	GSList *ptr;
 
@@ -352,7 +349,7 @@ gog_chart_foreach_elem (GogChart *chart, GogEnumFunc handler, gpointer data)
 	g_return_if_fail (chart->cardinality_valid);
 
 	for (ptr = chart->plots ; ptr != NULL ; ptr = ptr->next)
-		gog_plot_foreach_elem (ptr->data, handler, data);
+		gog_plot_foreach_elem (ptr->data, only_visible, handler, data);
 }
 
 gboolean
@@ -488,12 +485,12 @@ gog_chart_get_grid (GogChart const *chart)
 /*********************************************************************/
 
 typedef struct {
-	GogView base;
+	GogOutlinedView base;
 
 	/* indents */
 	double pre_x, post_x;
 } GogChartView;
-typedef GogViewClass	GogChartViewClass;
+typedef GogOutlinedViewClass	GogChartViewClass;
 
 #define GOG_CHART_VIEW_TYPE	(gog_chart_view_get_type ())
 #define GOG_CHART_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_CHART_VIEW_TYPE, GogChartView))
@@ -511,15 +508,7 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *allocation
 	GogAxis const *axis;
 	GogViewAllocation tmp, res = *allocation;
 	GogViewRequisition req;
-	double outline = gog_renderer_line_size (
-		view->renderer, chart->base.style->outline.width);
-	outline += gog_renderer_line_size (
-		view->renderer, chart->padding_pts);
 
-	res.x += outline;
-	res.y += outline;
-	res.w -= outline * 2.;
-	res.h -= outline * 2.;
 	(cview_parent_klass->size_allocate) (view, &res);
 
 	res = view->residual;
@@ -551,18 +540,18 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *allocation
 					tmp.w = res.w;
 					tmp.h = req.h;
 					switch (gog_axis_get_pos (axis)) {
-						case GOG_AXIS_AT_LOW:
-							post_y += req.h;
-							tmp.y   = res.y + res.h - post_y;
-							break;
-						case GOG_AXIS_AT_HIGH:
-							tmp.y  = res.y + pre_y;
-							pre_y += req.h;
-							break;
-						default:
-							break;
+					case GOG_AXIS_AT_LOW:
+						post_y += req.h;
+						tmp.y   = res.y + res.h - post_y;
+						break;
+					case GOG_AXIS_AT_HIGH:
+						tmp.y  = res.y + pre_y;
+						pre_y += req.h;
+						break;
+					default:
+						break;
 					}
-				break;
+					break;
 				case GOG_AXIS_Y:
 					/* Y axis take just the previous middle,
 					 * if it changes we'll iterate back */
@@ -570,16 +559,16 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *allocation
 					tmp.h = res.h - old_pre_y - old_post_y;
 					tmp.w = req.w;
 					switch (gog_axis_get_pos (axis)) {
-						case GOG_AXIS_AT_LOW:
-							tmp.x = res.x + pre_x;
-							pre_x  += req.w;
-							break;
-						case GOG_AXIS_AT_HIGH:
-							post_x  += req.w;
-							tmp.x = res.x + res.w - post_x;
-							break;
-						default:
-							break;
+					case GOG_AXIS_AT_LOW:
+						tmp.x = res.x + pre_x;
+						pre_x  += req.w;
+						break;
+					case GOG_AXIS_AT_HIGH:
+						post_x  += req.w;
+						tmp.x = res.x + res.w - post_x;
+						break;
+					default:
+						break;
 					}
 					break;
 
@@ -613,12 +602,25 @@ gog_chart_view_size_allocate (GogView *view, GogViewAllocation const *allocation
 
 static void
 gog_chart_view_render (GogView *view, GogViewAllocation const *bbox)
-{
-	GogChart *chart = GOG_CHART (view->model);
-	gog_renderer_push_style (view->renderer, chart->base.style);
-	gog_renderer_draw_rectangle (view->renderer, &view->allocation);
-	gog_renderer_pop_style (view->renderer);
+{        
+	GSList *ptr;        
+	GogView *child;        
+	gboolean clipped = FALSE;        
+	
 	(cview_parent_klass->render) (view, bbox);
+
+	for (ptr = view->children; ptr != NULL ; ptr = ptr->next) {                
+		child = ptr->data;                
+		/* All plots overlay the same region, simplify life                 
+		 * by clipping everything at once */                
+		if (!clipped && IS_GOG_PLOT (child->model)) {                        
+			gog_renderer_start_clipping (child->renderer, &child->allocation);                        
+			clipped = TRUE;                
+		}                
+		gog_view_render (child, bbox);        
+	}        
+	if (clipped)                
+		gog_renderer_stop_clipping (view->renderer);
 }
 
 static void
@@ -631,15 +633,18 @@ static void
 gog_chart_view_class_init (GogChartViewClass *gview_klass)
 {
 	GogViewClass *view_klass    = (GogViewClass *) gview_klass;
+	GogOutlinedViewClass *oview_klass = (GogOutlinedViewClass *) gview_klass;
 
 	cview_parent_klass = g_type_class_peek_parent (gview_klass);
 	view_klass->size_allocate   = gog_chart_view_size_allocate;
-	view_klass->render	    = gog_chart_view_render;
+	view_klass->render = gog_chart_view_render;
+
+	oview_klass->call_parent_render = FALSE;
 }
 
 static GSF_CLASS (GogChartView, gog_chart_view,
 		  gog_chart_view_class_init, gog_chart_view_init,
-		  GOG_VIEW_TYPE)
+		  GOG_OUTLINED_VIEW_TYPE)
 
 /**
  * gog_chart_view_get_indents :
