@@ -34,6 +34,7 @@ enum {
 	CHILD_ADDED,
 	CHILD_REMOVED,
 	CHILD_NAME_CHANGED,
+	CHILDREN_REORDERED,
 	NAME_CHANGED,
 	CHANGED,
 	LAST_SIGNAL
@@ -84,25 +85,28 @@ gog_object_class_init (GObjectClass *klass)
 		G_STRUCT_OFFSET (GogObjectClass, child_added),
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
-		G_TYPE_NONE,
-		1, G_TYPE_OBJECT);
+		G_TYPE_NONE,	1, G_TYPE_OBJECT);
 	gog_object_signals [CHILD_REMOVED] = g_signal_new ("child-removed",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GogObjectClass, child_removed),
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
-		G_TYPE_NONE,
-		1, G_TYPE_OBJECT);
+		G_TYPE_NONE,	1, G_TYPE_OBJECT);
 	gog_object_signals [CHILD_NAME_CHANGED] = g_signal_new ("child-name-changed",
 		G_TYPE_FROM_CLASS (gog_klass),
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (GogObjectClass, child_name_changed),
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
-		G_TYPE_NONE,
-		1, G_TYPE_OBJECT);
-
+		G_TYPE_NONE,	1, G_TYPE_OBJECT);
+	gog_object_signals [CHILDREN_REORDERED] = g_signal_new ("children-reordered",
+		G_TYPE_FROM_CLASS (klass),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (GogObjectClass, children_reordered),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE, 0);
 	gog_object_signals [NAME_CHANGED] = g_signal_new ("name-changed",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -212,6 +216,7 @@ gog_object_dup (GogObject const *src, GogObject *new_parent)
 			g_object_set_property (G_OBJECT (dst), props[n]->name, &val);
 			g_value_unset (&val);
 		}
+	g_free (props);
 
 	if (IS_GOG_DATASET (src)) {	/* convenience to save data */
 		GogDataset const *src_set = GOG_DATASET (src);
@@ -336,14 +341,44 @@ gog_object_set_name (GogObject *obj, char *name, GError **err)
 /**
  * gog_object_get_children :
  * @obj : a #GogObject
+ * @filter : an optional #GogObjectRole to use as a filter
  *
  * The list needs to be Freed
  **/
 GSList *
-gog_object_get_children (GogObject const *obj)
+gog_object_get_children (GogObject const *obj, GogObjectRole const *filter)
 {
+	GSList *ptr, *res = NULL;
+
 	g_return_val_if_fail (GOG_OBJECT (obj) != NULL, NULL);
-	return g_slist_copy (obj->children);
+
+	if (filter == NULL)
+		return g_slist_copy (obj->children);
+
+	for (ptr = obj->children ; ptr != NULL ; ptr = ptr->next)
+		if (GOG_OBJECT (ptr->data)->role == filter)
+			res = g_slist_prepend (res, ptr->data);
+	return g_slist_reverse (res);
+}
+
+/**
+ * gog_object_get_child_by_role :
+ * @obj : a #GogObject
+ * @role : a #GogObjectRole to use as a filter
+ *
+ * A convenience routine to handle a unique child
+ * Returns NULL and spews an error if there is more than one.
+ **/
+GogObject *
+gog_object_get_child_by_role (GogObject const *obj, GogObjectRole const *role)
+{
+	GogObject *res = NULL;
+	GSList *children = gog_object_get_children (obj, role);
+
+	if (children != NULL && children->next == NULL)
+		res = children->data;
+	g_slist_free (children);
+	return res;
 }
 
 /**
@@ -398,8 +433,15 @@ gog_role_cmp (GogObjectRole const *a, GogObjectRole const *b)
 		return 1;
 	else if (index_a > index_b)
 		return -1;
-	if (a->priority != b->priority)
-		return b->priority - a->priority;
+	return b->priority - a->priority;
+}
+
+static int
+gog_role_cmp_full (GogObjectRole const *a, GogObjectRole const *b)
+{
+	int res = gog_role_cmp (a, b);
+	if (res != 0)
+		return res;
 	return g_utf8_collate (a->id, b->id);
 }
 
@@ -425,27 +467,137 @@ gog_object_possible_additions (GogObject const *parent)
 		g_hash_table_foreach (klass->roles,
 			(GHFunc) cb_collect_possible_additions, &data);
 
-		return g_slist_sort (data.res, (GCompareFunc) gog_role_cmp);
+		return g_slist_sort (data.res, (GCompareFunc) gog_role_cmp_full);
 	}
 
 	return NULL;
 }
 
+/**
+ * gog_object_can_reorder :
+ * @obj : #GogObject
+ * @inc_ok : possibly NULL pointer.
+ * @dec_ok : possibly NULL pointer.
+ *
+ * If @obj can move forward or backward in its parents child list
+ **/
+void
+gog_object_can_reorder (GogObject const *obj, gboolean *inc_ok, gboolean *dec_ok)
+{
+	GogObject const *parent;
+	GSList *ptr;
+
+	g_return_if_fail (GOG_OBJECT (obj) != NULL);
+
+	if (inc_ok != NULL)
+		*inc_ok = FALSE;
+	if (dec_ok != NULL)
+		*dec_ok = FALSE;
+
+	if (obj->parent == NULL || gog_object_get_graph (obj) == NULL)
+		return;
+	parent = obj->parent;
+	ptr = parent->children;
+
+	g_return_if_fail (ptr != NULL);
+
+	/* find a pointer to the previous sibling */
+	if (ptr->data != obj) {
+		while (ptr->next != NULL && ptr->next->data != obj)
+			ptr = ptr->next;
+
+		g_return_if_fail (ptr->next != NULL);
+
+		if (inc_ok != NULL &&
+		    !gog_role_cmp (((GogObject *)ptr->data)->role, obj->role))
+			*inc_ok = TRUE;
+
+		ptr = ptr->next;
+	}
+
+	/* ptr now points at @obj */
+	if (dec_ok != NULL && ptr->next != NULL &&
+	    !gog_role_cmp (obj->role, ((GogObject *)ptr->next->data)->role))
+		*dec_ok = TRUE;
+}
+
+/**
+ * gog_object_reorder :
+ * @obj : #GogObject
+ * @inc :
+ * @goto_max :
+ *
+ * Returns the object just before @obj in the new ordering.
+ **/
+GogObject *
+gog_object_reorder (GogObject const *obj, gboolean inc, gboolean goto_max)
+{
+	GogObject *parent, *obj_follows;
+	GSList **ptr, *tmp;
+
+	g_return_val_if_fail (GOG_OBJECT (obj) != NULL, NULL);
+
+	if (obj->parent == NULL || gog_object_get_graph (obj) == NULL)
+		return NULL;
+	parent = obj->parent;
+
+	if (inc)
+		parent->children = g_slist_reverse (parent->children);
+
+	for (ptr = &parent->children; *ptr != NULL && (*ptr)->data != obj ;)
+		ptr = &(*ptr)->next;
+
+	g_return_val_if_fail (*ptr != NULL, NULL);
+	g_return_val_if_fail ((*ptr)->next != NULL, NULL);
+
+	tmp = *ptr;
+	*ptr = tmp->next;
+	ptr = &(*ptr)->next;
+
+	while (goto_max && *ptr != NULL &&
+	       !gog_role_cmp (obj->role, ((GogObject *)((*ptr)->data))->role))
+		ptr = &(*ptr)->next;
+
+	tmp->next = *ptr;
+	*ptr = tmp;
+
+	if (inc)
+		parent->children = g_slist_reverse (parent->children);
+
+	if (parent->children->data != obj) {
+		for (tmp = parent->children ; tmp->next->data != obj ; )
+			tmp = tmp->next;
+		obj_follows = tmp->data;
+	} else
+		obj_follows = NULL;
+
+	/* Pass the sibling that precedes obj, or NULL if is the head */
+	g_signal_emit (G_OBJECT (parent),
+		gog_object_signals [CHILDREN_REORDERED], 0);
+	gog_object_emit_changed (parent, TRUE);
+
+	return obj_follows;
+}
+
 /**
  * gog_object_get_editor :
  * @obj   : #GogObject
  * @dalloc : #GogDataAllocator
- * @cc     : #CommandContext
+ * @cc     : #GnmCmdContext
  *
  **/
 gpointer
-gog_object_get_editor (GogObject *obj,
-			  GogDataAllocator *dalloc, CommandContext *cc)
+gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
+		       GnmCmdContext *cc)
 {
 	GogObjectClass *klass = GOG_OBJECT_GET_CLASS (obj);
 	g_return_val_if_fail (klass != NULL, NULL);
-	if (klass->editor)
+	if (klass->editor) {
+		/* If there are pending updates do them before creating the editor
+		 * to avoid expensive widget changes later */
+		gog_graph_force_update (gog_object_get_graph (obj));
 		return (*klass->editor) (obj, dalloc, cc);
+	}
 	return NULL;
 }
 
@@ -591,7 +743,7 @@ gog_object_set_parent (GogObject *child, GogObject *parent,
 	/* Insert sorted based on hokey little ordering */
 	step = &parent->children;
 	while (*step != NULL &&
-	       gog_role_cmp (GOG_OBJECT ((*step)->data)->role, role) >= 0)
+	       gog_role_cmp_full (GOG_OBJECT ((*step)->data)->role, role) >= 0)
 		step = &((*step)->next);
 	*step = g_slist_prepend (*step, child);
 
