@@ -23,7 +23,7 @@
 
 #include <goffice/graph/goffice-graph.h>
 #include <glib-object.h>
-#include <command-context.h> /* for CommandContext */
+#include <command-context.h> /* for GnmCmdContext */
 #include <libart_lgpl/art_rect.h>
 
 G_BEGIN_DECLS
@@ -36,8 +36,9 @@ typedef enum {
 
 struct _GogObjectRole {
 	char const *id;	/* for persistence */
-
 	char const *is_a_typename;
+	unsigned    priority;
+
 	guint32		  	allowable_positions;
 	GogObjectPosition 	default_position;
 	GogObjectNamingConv	naming_conv;
@@ -86,7 +87,7 @@ typedef struct {
 	void	     (*parent_changed)	(GogObject *obj, gboolean was_set);
 	char const  *(*type_name)	(GogObject const *obj);
 	gpointer     (*editor)		(GogObject *obj,
-					 GogDataAllocator *dalloc, CommandContext *cc);
+					 GogDataAllocator *dalloc, GnmCmdContext *cc);
 
 	/* signals */
 	void (*changed)		(GogObject *obj, gboolean size);
@@ -95,6 +96,7 @@ typedef struct {
 	void (*child_added)	   (GogObject *parent, GogObject *child);
 	void (*child_removed)	   (GogObject *parent, GogObject *child);
 	void (*child_name_changed) (GogObject const *obj, GogObject const *child);
+	void (*children_reordered) (GogObject *obj);
 } GogObjectClass;
 
 #define GOG_OBJECT_TYPE		(gog_object_get_type ())
@@ -104,7 +106,8 @@ typedef struct {
 #define IS_GOG_OBJECT_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GOG_OBJECT_TYPE))
 #define GOG_OBJECT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_OBJECT_TYPE, GogObjectClass))
 
-#define GOG_PARAM_PERSISTENT	(1 << G_PARAM_USER_SHIFT)
+#define GOG_PARAM_PERSISTENT	(1 << (G_PARAM_USER_SHIFT+0))
+#define GOG_PARAM_FORCE_SAVE	(1 << (G_PARAM_USER_SHIFT+1))	/* even if the value == default */
 
 GType gog_object_get_type (void);
 
@@ -116,16 +119,24 @@ GogTheme    *gog_object_get_theme	 (GogObject const *obj);
 char const  *gog_object_get_id		 (GogObject const *obj);
 char const  *gog_object_get_name	 (GogObject const *obj);
 void	     gog_object_set_name	 (GogObject *obj, char *name, GError **err);
-GSList      *gog_object_get_children	 (GogObject const *obj);
+GSList      *gog_object_get_children	 (GogObject const *obj, GogObjectRole const *filter);
+GogObject   *gog_object_get_child_by_role(GogObject const *obj, GogObjectRole const *role);
 gpointer     gog_object_get_editor	 (GogObject *obj,
-					  GogDataAllocator *dalloc, CommandContext *cc);
-GogView	    *gog_object_new_view	 (GogObject const *obj, GogView *view);
-gboolean     gog_object_is_deletable	 (GogObject const *obj);
-GSList   *gog_object_possible_additions	 (GogObject const *obj);
-GogObject   *gog_object_add_by_role	 (GogObject *parent,
+					  GogDataAllocator *dalloc, GnmCmdContext *cc);
+GogView	  *gog_object_new_view	 	 (GogObject const *obj, GogView *view);
+gboolean   gog_object_is_deletable	 (GogObject const *obj);
+GSList    *gog_object_possible_additions (GogObject const *obj);
+GogObject *gog_object_add_by_role	 (GogObject *parent,
 					  GogObjectRole const *role, GogObject *child);
 GogObject   *gog_object_add_by_name	 (GogObject *parent,
 					  char const *role, GogObject *child);
+void		  gog_object_can_reorder (GogObject const *obj,
+					  gboolean *inc_ok, gboolean *dec_ok);
+GogObject	 *gog_object_reorder	 (GogObject const *obj,
+					  gboolean inc, gboolean goto_max);
+GogObjectPosition gog_object_get_pos	 (GogObject const *obj);
+gboolean	  gog_object_set_pos	 (GogObject *obj, GogObjectPosition p);
+
 GogObjectRole const *gog_object_find_role_by_name (GogObject const *obj,
 						   char const *role);
 
