@@ -42,7 +42,7 @@ struct _GogPlot {
 	GogChart	*chart;		/* potentially NULL */
 
 	GSList		*series;
-	unsigned	 cardinality;
+	unsigned	 full_cardinality, visible_cardinality;
 	gboolean	 cardinality_valid;
 	unsigned	 index_num;
 	gboolean	 vary_style_by_element;
@@ -61,16 +61,12 @@ typedef struct {
 	GType		series_type;
 
 	/* Virtuals */
-	unsigned   (*cardinality)  (GogPlot *plot);
-	gboolean   (*foreach_elem) (GogPlot *plot,
-				    GogEnumFunc handler, gpointer data);
 
 	GogAxisSet (*axis_set_pref)     (GogPlot const *plot);
 	gboolean   (*axis_set_is_valid) (GogPlot const *plot, GogAxisSet type);
 	gboolean   (*axis_set_assign)   (GogPlot *plot, GogAxisSet type);
-	GOData	  *(*axis_bounds) 	(GogPlot *plot, GogAxisType axis,
-					 double *min, double *max,
-					 double *logical_min, double *logical_max);
+	GOData	  *(*axis_get_bounds) 	(GogPlot *plot, GogAxisType axis,
+					 GogPlotBoundInfo *bounds);
 
 	gboolean   (*supports_vary_style_by_element) (GogPlot const *plot);
 } GogPlotClass;
