@@ -33,11 +33,18 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkhseparator.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkcheckbutton.h>
 
 #include <string.h>
 
 static GObjectClass *parent_klass;
 
+enum {
+	SERIES_PROP_0,
+	SERIES_HAS_LEGEND
+};
+
 static void
 gog_series_finalize (GObject *obj)
 {
@@ -53,6 +60,44 @@ gog_series_finalize (GObject *obj)
 		(parent_klass->finalize) (obj);
 }
 
+static void
+gog_series_set_property (GObject *obj, guint param_id,
+			 GValue const *value, GParamSpec *pspec)
+{
+	GogSeries *series = GOG_SERIES (obj);
+	gboolean b_tmp;
+
+	switch (param_id) {
+	case SERIES_HAS_LEGEND :
+		b_tmp = g_value_get_boolean (value);
+		if (series->has_legend ^ b_tmp) {
+			series->has_legend = b_tmp;
+			if (series->plot != NULL)
+				gog_plot_request_cardinality_update (series->plot);
+		}
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 return; /* NOTE : RETURN */
+	}
+
+	gog_object_emit_changed (GOG_OBJECT (obj), FALSE);
+}
+
+static void
+gog_series_get_property (GObject *obj, guint param_id,
+			 GValue *value, GParamSpec *pspec)
+{
+	GogSeries *series = GOG_SERIES (obj);
+
+	switch (param_id) {
+	case SERIES_HAS_LEGEND :
+		g_value_set_boolean (value, series->has_legend); 
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+}
+
 static unsigned
 make_dim_editor (GtkTable *table, unsigned row, GtkWidget *editor,
 		 char const *name, GogSeriesPriority priority, gboolean is_shared)
@@ -69,16 +114,25 @@ make_dim_editor (GtkTable *table, unsigned row, GtkWidget *editor,
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-	gnm_setup_label_atk (GTK_LABEL (label), editor);
+	gnm_setup_label_atk (label, editor);
 
 	return row + 1;
 }
 
+static void
+cb_show_in_legend (GtkToggleButton *b, GObject *series)
+{
+	g_object_set (series,
+		"has-legend", gtk_toggle_button_get_active (b),
+		NULL);
+}
+
 static gpointer
 gog_series_editor (GogObject *gobj,
 		   GogDataAllocator *dalloc,
-		   CommandContext *cc)
+		   GnmCmdContext *cc)
 {
+	static guint series_pref_page = 1;
 	GtkWidget *w;
 	GtkTable  *table;
 	unsigned i, row = 0;
@@ -124,12 +178,24 @@ gog_series_editor (GogObject *gobj,
 				gog_data_allocator_editor (dalloc, set, i, FALSE),
 				desc->dim[i].name, desc->dim[i].priority, TRUE);
 
+	gtk_table_attach (table, gtk_hseparator_new (),
+		0, 2, row, row+1, GTK_FILL, 0, 5, 3);
+	row++;
+	w = gtk_check_button_new_with_mnemonic ("_Show in Legend");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+		gog_series_has_legend (series));
+	g_signal_connect (G_OBJECT (w),
+		"toggled",
+		G_CALLBACK (cb_show_in_legend), series);
+	gtk_table_attach (table, w,
+		0, 2, row, row+1, GTK_FILL, 0, 5, 3);
 	gtk_widget_show_all (GTK_WIDGET (table));
 
 	w = gtk_notebook_new ();
 	gtk_notebook_prepend_page (GTK_NOTEBOOK (w), GTK_WIDGET (table),
 		gtk_label_new (_("Data")));
-	gog_style_editor (gobj, cc, w, desc->style_fields);
+	gog_style_editor (GOG_STYLED_OBJECT (gobj), cc, w);
+	gog_style_handle_notebook (w, &series_pref_page);
 	return w;
 }
 
@@ -140,11 +206,13 @@ gog_series_update (GogObject *obj)
 	series->needs_recalc = FALSE;
 }
 
-static unsigned
-gog_series_interesting_fields (GogStyledObject *obj)
+static void
+gog_series_init_style (GogStyledObject *gso, GogStyle *style)
 {
-	GogSeries const *series = (GogSeries const *)obj;
-	return series->plot->desc.series.style_fields;
+	GogSeries const *series = (GogSeries const *)gso;
+	style->interesting_fields = series->plot->desc.series.style_fields;
+	gog_theme_init_style (gog_object_get_theme (GOG_OBJECT (gso)),
+		style, GOG_OBJECT (gso), series->index);
 }
 
 static void
@@ -156,9 +224,18 @@ gog_series_class_init (GogSeriesClass *klass)
 
 	parent_klass = g_type_class_peek_parent (klass);
 	gobject_klass->finalize		= gog_series_finalize;
+	gobject_klass->set_property	= gog_series_set_property;
+	gobject_klass->get_property	= gog_series_get_property;
+
 	gog_klass->editor		= gog_series_editor;
 	gog_klass->update		= gog_series_update;
-	style_klass->interesting_fields = gog_series_interesting_fields;
+	style_klass->init_style 	= gog_series_init_style;
+
+	g_object_class_install_property (gobject_klass, SERIES_HAS_LEGEND,
+		g_param_spec_boolean ("has-legend", "has-legend",
+			"Should the series show up in legends",
+			TRUE,
+			G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 }
 
 static void
@@ -168,6 +245,7 @@ gog_series_init (GogSeries *series)
 	GOG_OBJECT (series)->use_parent_as_proxy = TRUE;
 
 	series->is_valid = FALSE;
+	series->has_legend = TRUE;
 	series->plot = NULL;
 	series->values = NULL;
 	series->index = -1;
@@ -306,6 +384,19 @@ gog_series_check_validity (GogSeries *series)
 	series->is_valid = TRUE;
 }
 
+/**
+ * gog_series_has_legend :
+ * @series : #GogSeries
+ *
+ * Returns TRUE if the series has a visible legend entry
+ **/
+gboolean
+gog_series_has_legend (GogSeries const *series)
+{
+	g_return_val_if_fail (GOG_SERIES (series) != NULL, FALSE);
+	return series->has_legend;
+}
+
 /**
  * gog_series_set_index :
  * @series : #GogSeries
@@ -336,8 +427,8 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 		return;
 
 	series->index = ind;
-	gog_theme_init_style (gog_object_get_theme (GOG_OBJECT (series)),
-		series->base.style, GOG_OBJECT (series), ind);
+	gog_styled_object_apply_theme (&series->base, series->base.style);
+	gog_styled_object_style_changed (GOG_STYLED_OBJECT (series));
 }
 
 /**
