@@ -112,45 +112,6 @@ gog_pie_plot_editor (GogObject *item,
 	return gog_pie_plot_pref (GOG_PIE_PLOT (item), cc);
 }
 
-static gboolean
-gog_pie_plot_foreach_elem (GogPlot *plot, GogEnumFunc handler, gpointer data)
-{
-	unsigned i, n, num_labels = 0;
-	GogPiePlot const *model = GOG_PIE_PLOT (plot);
-	GogSeries const *series;
-	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
-	GogStyle *style;
-	GODataVector *labels;
-	char *label;
-
-	if (!model->base.vary_style_by_element  || plot->series == NULL)
-		return FALSE;
-
-	series = plot->series->data; /* start with the first */
-	i = 0;
-	n = model->base.cardinality;
-	style = gog_style_dup (series->base.style);
-	labels = NULL;
-	if (series->values[0].data != NULL) {
-		labels = GO_DATA_VECTOR (series->values[0].data);
-		num_labels = go_data_vector_get_len (labels);
-	}
-	for ( ; i < n ; i++) {
-		gog_theme_init_style (theme, style, GOG_OBJECT (series),
-			model->base.index_num + i);
-		if (labels != NULL)
-			label = (i < num_labels)
-				? go_data_vector_get_str (labels, i) : g_strdup ("");
-		if (label == NULL)
-			label = g_strdup_printf ("%d", i);
-		(handler) (i, style, label, data);
-		g_free (label);
-	}
-	g_object_unref (style);
-
-	return TRUE;
-}
-
 static void
 gog_pie_plot_update (GogObject *obj)
 {
@@ -202,7 +163,6 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = 1;
 	plot_klass->series_type  = gog_pie_series_get_type ();
-	plot_klass->foreach_elem = gog_pie_plot_foreach_elem;
 }
 
 static void
@@ -372,22 +332,26 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (index > num_series) /* people snuck extra series into a pie */
 			break;
 
-		has_hole = center_radius > 0.;
-		r_int = center_radius + r * ((double)index - 1.0) / (double)num_series;
-		r_ext = center_radius + r * (double)index / (double)num_series;
-
 		style = GOG_STYLED_OBJECT (series)->style;
 		if (model->base.vary_style_by_element)
 			style = gog_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
+		if (num_series == index)
+			r -= 2 * gog_renderer_line_size (
+				view->renderer, style->outline.width);
+
+		has_hole = center_radius > 0.;
+		r_int = center_radius + r * ((double)index - 1.0) / (double)num_series;
+		r_ext = center_radius + r * (double)index / (double)num_series;
+
 		theta = (model->initial_angle + series->initial_angle) * 2. * M_PI / 360. - M_PI / 2.;
 
 		scale = 2 * M_PI / series->total;
 		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
 		for (k = 0 ; k < series->base.num_elements; k++) {
 			len = fabs (vals[k]) * scale;
-			if (!finite (len) || len < 1e-3)
+			if (!finitegnum (len) || len < 1e-3)
 				continue;
 
 			/* only separate the outer ring */
@@ -534,7 +498,7 @@ gog_pie_series_update (GogObject *obj)
 	series->base.num_elements = len;
 
 	for (total = 0. ; len-- > 0 ;)
-		if (finite (vals[len]))
+		if (finitegnum (vals[len]))
 			total += fabs (vals[len]);
 	series->total = total;
 
