@@ -27,6 +27,7 @@
 #include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
+#include "help.h"
 
 #include <sheet.h>
 #include <cell.h>
@@ -38,6 +39,8 @@
 #include <workbook-edit.h>
 
 #include <glade/glade.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtktogglebutton.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include "filter.h"
 
@@ -57,14 +60,14 @@ static void
 advanced_filter_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
 				       AdvancedFilterState *state)
 {
-        Value *output_range   = NULL;
-        Value *input_range    = NULL;
-        Value *criteria_range = NULL;
+        GnmValue *output_range   = NULL;
+        GnmValue *input_range    = NULL;
+        GnmValue *criteria_range = NULL;
 
 	int i;
 
         input_range = gnm_expr_entry_parse_as_value (
-		GNUMERIC_EXPR_ENTRY (state->input_entry), state->sheet);
+		GNM_EXPR_ENTRY (state->input_entry), state->sheet);
 	if (input_range == NULL) {
 		gtk_label_set_text (GTK_LABEL (state->warning),
 				    _("The list range is invalid."));
@@ -86,7 +89,7 @@ advanced_filter_update_sensitivity_cb (G_GNUC_UNUSED GtkWidget *dummy,
 	i = gnumeric_glade_group_value (state->gui, output_group);
 	if (i == 2) {
 		output_range = gnm_expr_entry_parse_as_value
-			(GNUMERIC_EXPR_ENTRY (state->output_entry),
+			(GNM_EXPR_ENTRY (state->output_entry),
 			 state->sheet);
 		if (output_range == NULL) {
 			gtk_label_set_text (GTK_LABEL (state->warning),
@@ -116,15 +119,15 @@ advanced_filter_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 			       AdvancedFilterState *state)
 {
 	data_analysis_output_t  dao;
-	Value                   *input;
-	Value                   *criteria;
+	GnmValue                   *input;
+	GnmValue                   *criteria;
 	char                    *text;
 	GtkWidget               *w;
 	int                     err = 0;
 	gboolean                unique;
 
 	input = gnm_expr_entry_parse_as_value (
-		GNUMERIC_EXPR_ENTRY (state->input_entry), state->sheet);
+		GNM_EXPR_ENTRY (state->input_entry), state->sheet);
 
 	criteria = gnm_expr_entry_parse_as_value
 		(state->input_entry_2, state->sheet);
@@ -191,7 +194,7 @@ dialog_advanced_filter (WorkbookControlGUI *wbcg)
 	state = g_new (AdvancedFilterState, 1);
 
 	if (dialog_tool_init (state, wbcg, wb_control_cur_sheet (wbc),
-			      "filters.html",
+			      GNUMERIC_HELP_LINK_ADVANCED_FILTER,
 			      "advanced-filter.glade", "Filter",
 			      _("_List Range:"), _("Criteria _Range:"),
 			      _("Could not create the Advanced Filter dialog."),
