@@ -30,7 +30,9 @@
 #include "sheet.h"
 #include "workbook.h"
 #include "str.h"
+#include "position.h"
 #include "format.h"
+#include "auto-format.h"
 #include "ranges.h"
 #include "parse-util.h"
 #include <goffice/graph/go-data-impl.h>
@@ -38,14 +40,14 @@
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
-static Dependent *gnm_go_data_get_dep (GOData const *obj);
+static GnmDependent *gnm_go_data_get_dep (GOData const *obj);
 
 static  GOData *
 gnm_go_data_dup (GOData const *src)
 {
 	GOData *dst = g_object_new (G_OBJECT_TYPE (src), NULL);
-	Dependent const *src_dep = gnm_go_data_get_dep (src);
-	Dependent *dst_dep = gnm_go_data_get_dep (dst);
+	GnmDependent const *src_dep = gnm_go_data_get_dep (src);
+	GnmDependent *dst_dep = gnm_go_data_get_dep (dst);
 
 	dst_dep->expression = src_dep->expression;
 	dst_dep->sheet      = src_dep->sheet;
@@ -62,8 +64,8 @@ gnm_go_data_dup (GOData const *src)
 static gboolean
 gnm_go_data_eq (GOData const *data_a, GOData const *data_b)
 {
-	Dependent const *a = gnm_go_data_get_dep (data_a);
-	Dependent const *b = gnm_go_data_get_dep (data_b);
+	GnmDependent const *a = gnm_go_data_get_dep (data_a);
+	GnmDependent const *b = gnm_go_data_get_dep (data_b);
 	if (a->expression == NULL && b->expression == NULL) {
 		char const *str_a = g_object_get_data (G_OBJECT (data_a), "from-str");
 		char const *str_b = g_object_get_data (G_OBJECT (data_b), "from-str");
@@ -76,11 +78,20 @@ gnm_go_data_eq (GOData const *data_a, GOData const *data_b)
 	return gnm_expr_equal (a->expression, b->expression);
 }
 
+static GOFormat *
+gnm_go_data_preferred_fmt (GOData const *dat)
+{
+	GnmEvalPos ep;
+	GnmDependent const *dep = gnm_go_data_get_dep (dat);
+	return auto_style_format_suggest (dep->expression,
+		eval_pos_init_dep (&ep, dep));
+}
+
 static char *
 gnm_go_data_as_str (GOData const *dat)
 {
-	ParsePos pp;
-	Dependent const *dep = gnm_go_data_get_dep (dat);
+	GnmParsePos pp;
+	GnmDependent const *dep = gnm_go_data_get_dep (dat);
 	if (dep->sheet == NULL)
 		return g_strdup ("No sheet for GnmGOData");
 	return gnm_expr_as_string (dep->expression,
@@ -92,8 +103,8 @@ static  gboolean
 gnm_go_data_from_str (GOData *dat, char const *str)
 {
 	GnmExpr const *expr;
-	ParsePos   pp;
-	Dependent *dep = gnm_go_data_get_dep (dat);
+	GnmParsePos   pp;
+	GnmDependent *dep = gnm_go_data_get_dep (dat);
 
 	/* Its too early in the life cycle to know where we
 	 * are.  Wait until later when we parse the sheet */
@@ -115,7 +126,7 @@ gnm_go_data_from_str (GOData *dat, char const *str)
 void
 gnm_go_data_set_sheet (GOData *dat, Sheet *sheet)
 {
-	Dependent *dep = gnm_go_data_get_dep (dat);
+	GnmDependent *dep = gnm_go_data_get_dep (dat);
 
 	if (dep == NULL)
 		return;
@@ -147,7 +158,7 @@ gnm_go_data_set_sheet (GOData *dat, Sheet *sheet)
 
 struct _GnmGODataScalar {
 	GODataScalar	 base;
-	Dependent	 dep;
+	GnmDependent	 dep;
 	GnmValue	*val;
 	char		*val_str;
 };
@@ -168,7 +179,7 @@ scalar_get_val (GnmGODataScalar *scalar)
 	}
 	if (scalar->val == NULL) {
 		if (scalar->dep.expression != NULL) {
-			EvalPos pos;
+			GnmEvalPos pos;
 			scalar->val = gnm_expr_eval (scalar->dep.expression,
 				eval_pos_init_dep (&pos, &scalar->dep),
 				GNM_EXPR_EVAL_PERMIT_EMPTY);
@@ -179,7 +190,7 @@ scalar_get_val (GnmGODataScalar *scalar)
 }
 
 static void
-gnm_go_data_scalar_eval (Dependent *dep)
+gnm_go_data_scalar_eval (GnmDependent *dep)
 {
 	GnmGODataScalar *scalar = DEP_TO_SCALAR (dep);
 
@@ -234,6 +245,7 @@ gnm_go_data_scalar_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize		= gnm_go_data_scalar_finalize;
 	godata_klass->dup		= gnm_go_data_dup;
 	godata_klass->eq		= gnm_go_data_eq;
+	godata_klass->preferred_fmt	= gnm_go_data_preferred_fmt;
 	godata_klass->as_str		= gnm_go_data_as_str;
 	godata_klass->from_str		= gnm_go_data_from_str;
 	scalar_klass->get_value		= gnm_go_data_scalar_get_value;
@@ -241,7 +253,7 @@ gnm_go_data_scalar_class_init (GObjectClass *gobject_klass)
 }
 
 static void
-gnm_go_data_scalar_debug_name (Dependent const *dep, FILE *out)
+gnm_go_data_scalar_debug_name (GnmDependent const *dep, FILE *out)
 {
 	fprintf (out, "GraphScalar%p", dep);
 }
@@ -272,7 +284,7 @@ gnm_go_data_scalar_new_expr (Sheet *sheet, GnmExpr const *expr)
 
 struct _GnmGODataVector {
 	GODataVector	base;
-	Dependent	 dep;
+	GnmDependent	 dep;
 	GnmValue	*val;
 	gboolean	 as_col;
 };
@@ -283,7 +295,7 @@ typedef GODataVectorClass GnmGODataVectorClass;
 static GObjectClass *vector_parent_klass;
 
 static void
-gnm_go_data_vector_eval (Dependent *dep)
+gnm_go_data_vector_eval (GnmDependent *dep)
 {
 	GnmGODataVector *vec = DEP_TO_VECTOR (dep);
 
@@ -317,7 +329,7 @@ static void
 gnm_go_data_vector_load_len (GODataVector *dat)
 {
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
-	EvalPos ep;
+	GnmEvalPos ep;
 	GnmRange r;
 	Sheet *start_sheet, *end_sheet;
 	unsigned h, w;
@@ -385,7 +397,7 @@ struct assign_closure {
 
 static GnmValue *
 cb_assign_val (Sheet *sheet, int col, int row,
-	       Cell *cell, struct assign_closure *dat)
+	       GnmCell *cell, struct assign_closure *dat)
 {
 	GnmValue *v;
 	double res;
@@ -406,7 +418,7 @@ cb_assign_val (Sheet *sheet, int col, int row,
 		v = format_match_number (v->v_str.val->str, NULL,
 				workbook_date_conv (sheet->workbook));
 		if (v == NULL) {
-			dat->vals[dat->i++] = gnm_nan;
+			dat->vals[dat->i++] = gnm_pinf;
 			return NULL;
 		}
 		res = value_get_as_float (v);
@@ -426,7 +438,7 @@ static void
 gnm_go_data_vector_load_values (GODataVector *dat)
 {
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
-	EvalPos ep;
+	GnmEvalPos ep;
 	GnmRange r;
 	Sheet *start_sheet, *end_sheet;
 	int len = go_data_vector_get_len (dat); /* force calculation */
@@ -465,7 +477,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 
 		/* In case the sheet is empty */
 		if (r.start.col <= r.end.col && r.start.row <= r.end.row) {
-			closure.maximum = G_MINDOUBLE;
+			closure.maximum = - G_MAXDOUBLE;
 			closure.minimum = G_MAXDOUBLE;
 			closure.vals = dat->values;
 			closure.last = -1;
@@ -481,7 +493,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 		break;
 
 	case VALUE_ARRAY :
-		maximum = G_MINDOUBLE;
+		maximum = - G_MAXDOUBLE;
 		minimum = G_MAXDOUBLE;
 		while (len-- > 0) {
 			v = vec->as_col
@@ -538,14 +550,14 @@ gnm_go_data_vector_get_value (GODataVector *dat, unsigned i)
 {
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
 	GnmValue *v;
-	EvalPos ep;
+	GnmEvalPos ep;
 	gboolean valid;
 
 	if (vec->val == NULL)
 		gnm_go_data_vector_load_len (dat);
 
 	eval_pos_init_dep (&ep, &vec->dep);
-	v = value_duplicate (vec->as_col
+	v = value_dup (vec->as_col
 		? value_area_get_x_y (vec->val, 0, i, &ep)
 		: value_area_get_x_y (vec->val, i, 0, &ep));
 	v = value_coerce_to_number (v, &valid, &ep);
@@ -563,8 +575,8 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 {
 	GnmGODataVector *vec = (GnmGODataVector *)dat;
 	GnmValue const *v;
-	EvalPos ep;
-	StyleFormat const *format = NULL;
+	GnmEvalPos ep;
+	GnmFormat const *format = NULL;
 	GnmDateConventions const *date_conv = NULL;
 
 	if (vec->val == NULL)
@@ -576,7 +588,7 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 	eval_pos_init_dep (&ep, &vec->dep);
 	if (v->type == VALUE_CELLRANGE) {
 		Sheet *start_sheet, *end_sheet;
-		Cell  *cell;
+		GnmCell  *cell;
 		GnmRange  r;
 
 		rangeref_normalize (&v->v_range.cell, &ep,
@@ -618,6 +630,7 @@ gnm_go_data_vector_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize		= gnm_go_data_vector_finalize;
 	godata_klass->dup		= gnm_go_data_dup;
 	godata_klass->eq		= gnm_go_data_eq;
+	godata_klass->preferred_fmt	= gnm_go_data_preferred_fmt;
 	godata_klass->as_str		= gnm_go_data_as_str;
 	godata_klass->from_str		= gnm_go_data_from_str;
 	vector_klass->load_len		= gnm_go_data_vector_load_len;
@@ -627,7 +640,7 @@ gnm_go_data_vector_class_init (GObjectClass *gobject_klass)
 }
 
 static void
-gnm_go_data_vector_debug_name (Dependent const *dep, FILE *out)
+gnm_go_data_vector_debug_name (GnmDependent const *dep, FILE *out)
 {
 	fprintf (out, "GraphVector%p", dep);
 }
@@ -655,7 +668,7 @@ gnm_go_data_vector_new_expr (Sheet *sheet, GnmExpr const *expr)
 
 /*******************************************************************************/
 
-static Dependent *
+static GnmDependent *
 gnm_go_data_get_dep (GOData const *dat)
 {
 	if (IS_GNM_GO_DATA_SCALAR (dat))
