@@ -5,18 +5,25 @@
 #include "error-info.h"
 #include "command-context.h"
 #include "gutils.h"
-#include <gtk/gtk.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkcombo.h>
+#include <gtk/gtkfilesel.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkmenu.h>
+#include <gtk/gtktoolbar.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtkentry.h>
 #include <glade/glade-xml.h>
 
 gboolean   gnumeric_dialog_question_yes_no (WorkbookControlGUI *wbcg,
-                                            const gchar *message,
+                                            char const *message,
                                             gboolean default_answer);
 gboolean   gnumeric_dialog_file_selection (WorkbookControlGUI *wbcg, 
 					   GtkFileSelection *fsel);
 gboolean   gnumeric_dialog_dir_selection (WorkbookControlGUI *wbcg, 
 					  GtkFileSelection *fsel);
 void       gnumeric_notice (WorkbookControlGUI *wbcg, GtkMessageType type, 
-			    const char *str);
+			    char const *str);
 void       gnumeric_notice_nonmodal (GtkWindow *parent, GtkWidget **ref,
 				     GtkMessageType type, char const *str);
 
@@ -28,20 +35,20 @@ void       gnumeric_error_info_dialog_show (WorkbookControlGUI *wbcg,
 void       gnumeric_set_transient (GtkWindow *parent, GtkWindow *window);
 void       gnumeric_keyed_dialog (WorkbookControlGUI *wbcg,
 				  GtkWindow *dialog,
-				  const char *key);
+				  char const *key);
 gpointer   gnumeric_dialog_raise_if_exists (WorkbookControlGUI *wbcg,
-					    const char *key);
-void       gnumeric_editable_enters (GtkWindow *window, GtkWidget *w);
-void       gnumeric_combo_enters (GtkWindow *window, GtkCombo *combo);
+					    char const *key);
+void       gnumeric_editable_enters	(GtkWindow *window, GtkWidget *w);
+void       gnumeric_combo_enters	(GtkWindow *window, GtkWidget *combo);
 void       gnumeric_toolbar_insert_with_eventbox (GtkToolbar *toolbar,
                                                   GtkWidget  *widget,
-                                                  const char *tooltip_text,
-                                                  const char *tooltip_private_text,
+                                                  char const *tooltip_text,
+                                                  char const *tooltip_private_text,
                                                   gint        position);
 void       gnumeric_toolbar_append_with_eventbox (GtkToolbar *toolbar,
                                                   GtkWidget  *widget,
-                                                  const char *tooltip_text,
-                                                  const char *tooltip_private_text);
+                                                  char const *tooltip_text,
+                                                  char const *tooltip_private_text);
 
 /* change alignment of a stock buttons content (should be removed for 2.2) */
 void gtk_button_stock_alignment_set (GtkButton *button,
@@ -53,7 +60,7 @@ void gtk_button_stock_alignment_set (GtkButton *button,
 /* Utility routine as Gtk does not have any decent routine to do this */
 int gtk_radio_group_get_selected (GSList *radio_group);
 /* Utility routine as libglade does not have any decent routine to do this */
-int gnumeric_glade_group_value (GladeXML *gui, const char *group[]);
+int gnumeric_glade_group_value (GladeXML *gui, char const *group[]);
 
 /* Use this on menus that are popped up */
 void gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event);
@@ -64,7 +71,7 @@ void gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event);
 void        gnumeric_position_tooltip (GtkWidget *tip, int horizontal);
 GtkWidget  *gnumeric_create_tooltip (void);
 
-GladeXML   *gnm_glade_xml_new (CommandContext *cc, char const * gladefile,
+GladeXML   *gnm_glade_xml_new (GnmCmdContext *cc, char const *gladefile,
 			       char const *root, char const *domain);
 
 void 	    gnumeric_inject_widget_into_bonoboui (WorkbookControlGUI *wbcg,
@@ -72,8 +79,8 @@ void 	    gnumeric_inject_widget_into_bonoboui (WorkbookControlGUI *wbcg,
 						  char const *path);
 
 typedef struct {
-	char const * name;
-	char const * pixmap;
+	char const *name;
+	char const *pixmap;
 	int display_filter;
 	int sensitive_filter;
 
@@ -92,7 +99,7 @@ void gnumeric_create_popup_menu (GnumericPopupMenuElement const *elements,
 
 #define gnumeric_filter_modifiers(a) ((a) &(~(GDK_LOCK_MASK|GDK_MOD2_MASK|GDK_MOD5_MASK)))
 
-StyleColor *color_combo_get_style_color (GtkWidget *color_combo);
+GnmColor *color_combo_get_style_color (GtkWidget *color_combo);
 
 GtkWidget *gnumeric_toolbar_new (WorkbookControlGUI *wbcg, gpointer info,
 				  char const *name, gint band_num, gint band_position, gint offset);
@@ -112,9 +119,9 @@ void focus_on_entry (GtkEntry *entry);
 #define entry_to_float(entry, the_float, update)	\
 	entry_to_float_with_format (entry, the_float, update, NULL)
 gboolean entry_to_float_with_format (GtkEntry *entry, gnm_float *the_float, gboolean update,
-				     StyleFormat *format);
+				     GnmFormat *format);
 gboolean entry_to_float_with_format_default (GtkEntry *entry, gnm_float *the_float, gboolean update,
-					     StyleFormat *format, gnm_float num);
+					     GnmFormat *format, gnm_float num);
 gboolean entry_to_int	(GtkEntry *entry, gint *the_int, gboolean update);
 void	 float_to_entry	(GtkEntry *entry, gnm_float the_float);
 void	 int_to_entry	(GtkEntry *entry, gint the_int);
@@ -122,11 +129,11 @@ void	 int_to_entry	(GtkEntry *entry, gint the_int);
 GtkWidget *gnumeric_load_image  (char const *name);
 GdkPixbuf *gnumeric_load_pixbuf (char const *name);
 
-GdkPixbuf *gnm_pixbuf_tile (const GdkPixbuf *src, int w, int h);
+GdkPixbuf *gnm_pixbuf_tile (GdkPixbuf const *src, int w, int h);
 
 void gnm_setup_label_atk (GtkWidget *label, GtkWidget *target);
 
-int gnm_measure_string (PangoContext *context, const PangoFontDescription *font_desc, const char *str);
+int gnm_measure_string (PangoContext *context, PangoFontDescription const *font_desc, char const *str);
 
 void gnm_link_button_and_entry (GtkWidget *button, GtkWidget *entry);
 
@@ -134,14 +141,14 @@ void gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct);
 void gnm_widget_set_cursor (GtkWidget *w, GdkCursor *ct);
 GdkCursor *gnm_fat_cross_cursor (GdkDisplay *display);
 
-GtkWidget * gnumeric_button_new_with_stock_image (const gchar* text, const gchar* stock_id);
-GtkWidget * gnumeric_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
+GtkWidget * gnumeric_button_new_with_stock_image (char const *text, char const *stock_id);
+GtkWidget * gnumeric_dialog_add_button (GtkDialog *dialog, char const *text, char const *stock_id,
 					gint response_id);
 GtkWidget * gnumeric_message_dialog_new (GtkWindow * parent,
 					 GtkDialogFlags flags,
 					 GtkMessageType type,
-					 gchar const * primary_message,
-					 gchar const * secondary_message);
+					 char const *primary_message,
+					 char const *secondary_message);
 
 GdkPixbuf* gnm_pixbuf_intelligent_scale (GdkPixbuf *pixbuf, 
 					 guint width, guint height);
