@@ -18,8 +18,8 @@ void init_init (char const* gnumeric_binary);
 poptContext gnumeric_arg_parse    (int argc, char *argv []);
 void	    gnumeric_arg_shutdown (void);
 
-void gnm_common_init (void);
-int  gnm_dump_func_defs  (char const* filename, gboolean def_or_state);
-void gnm_shutdown (void);
+void gnm_common_init	(gboolean fast);
+int  gnm_dump_func_defs (char const* filename, gboolean def_or_state);
+void gnm_shutdown	(void);
 
 #endif
