@@ -540,7 +540,6 @@ render_path (GString *target, HFRenderInfo *info, char const *args)
 		char *filename_utf8 = workbook_get_filename_utf8 
 			(info->sheet->workbook, FALSE);
 		char *dir;
-		char *path;
 		char *path_n_file;
 
 		if (g_path_is_absolute (filename_utf8))
@@ -554,12 +553,9 @@ render_path (GString *target, HFRenderInfo *info, char const *args)
 			g_free (current_dir);
 		}
 		dir = g_path_get_dirname (path_n_file);
-		path = g_build_path (G_DIR_SEPARATOR_S, dir, 
-				     G_DIR_SEPARATOR_S, NULL);
-		g_string_append (target, path);
-		g_free (path);
-		g_free (path_n_file);
+		g_string_append (target, dir);
 		g_free (dir);
+		g_free (path_n_file);
 	} else 
 		g_string_append (target, _("Path "));
 }
