@@ -3,6 +3,7 @@
 #define GNUMERIC_SHEET_OBJECT_PRIV_H
 
 #include "sheet-object.h"
+#include <libxml/tree.h>
 #include <glib-object.h>
 #include <gtk/gtkmenu.h>
 #include <libgnomeprint/gnome-print.h>
@@ -42,10 +43,18 @@ typedef struct {
 	void           (*set_active) (SheetObject	*so,
 				      GObject           *obj_view,
 				      gboolean		val);
-	gboolean	 (*read_xml) (SheetObject	*so,
+	gboolean     (*read_xml_dom) (SheetObject	*so,
+				      char const *type_name,	/* for versioning */
 				      XmlParseContext const *ctxt,
 				      xmlNodePtr	tree);
-	gboolean	(*write_xml) (SheetObject const *so,
+	gboolean    (*write_xml_dom) (SheetObject const *so,
+				      XmlParseContext const *ctxt,
+				      xmlNodePtr	tree);
+	gboolean     (*read_xml_sax) (SheetObject	*so,
+				      char const *type_name,	/* for versioning */
+				      XmlParseContext const *ctxt,
+				      xmlNodePtr	tree);
+	gboolean    (*write_xml_sax) (SheetObject const *so,
 				      XmlParseContext const *ctxt,
 				      xmlNodePtr	tree);
 
@@ -61,11 +70,22 @@ typedef struct {
 	void (*default_size)	 (SheetObject const *so,
 				  double *width_pts, double *height_pts);
 
+	void (*func_pad1)	(void);
+	void (*func_pad2)	(void);
+	void (*func_pad3)	(void);
+	void (*func_pad4)	(void);
+
 	gboolean rubber_band_directly; /* If false, we draw a rectangle where
 					* the object is going to be layed out
 					* If true, we draw the object while
 					* laying it out on the sheet
 					*/
+	char const *xml_export_name;
+
+	void *data_pad1;
+	void *data_pad2;
+	void *data_pad3;
+	void *data_pad4;
 } SheetObjectClass;
 
 #define SHEET_OBJECT_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), SHEET_OBJECT_TYPE, SheetObjectClass))
