@@ -6,7 +6,7 @@
 #include "gnumeric.h"
 
 #define DEFAULT_FONT "Sans"
-#define DEFAULT_SIZE 9.0
+#define DEFAULT_SIZE 10.0
 #define GCONF_DEFAULT_FONT "/apps/gnumeric/core/defaultfont/name"
 #define GCONF_DEFAULT_SIZE "/apps/gnumeric/core/defaultfont/size"
 
@@ -35,7 +35,7 @@ typedef enum _StyleUnderlineType {
 	UNDERLINE_DOUBLE = 2
 } StyleUnderlineType;
 
-struct _StyleFont {
+struct _GnmFont {
 	int	 ref_count;
 	char	*font_name;
 	double	 size_pts;
@@ -46,6 +46,7 @@ struct _StyleFont {
 			double digit, decimal, sign, E, e, hash;
 		} pixels, pts;
 	} approx_width;
+	double	 height;
 	struct {
 		PangoContext		*context;
 		PangoFontMetrics	*metrics;
@@ -63,25 +64,27 @@ struct _StyleFont {
 void           style_init  	      (void);
 void	       style_shutdown         (void);
 
-StyleFont     *style_font_new         (PangoContext *context,
+GnmFont     *style_font_new         (PangoContext *context,
 				       const char *font_name,
 				       double size_pts, double scale,
 				       gboolean bold, gboolean italic);
-StyleFont     *style_font_new_simple  (PangoContext *context,
-				       const char *font_name,
-				       double size_pts, double scale,
-				       gboolean bold, gboolean italic);
-void style_font_ref          (StyleFont *sf);
-void style_font_unref        (StyleFont *sf);
+void style_font_ref          (GnmFont *sf);
+void style_font_unref        (GnmFont *sf);
 
 guint          style_font_hash_func (gconstpointer v);
 gint           style_font_equal (gconstpointer v, gconstpointer v2);
 
-SpanCalcFlags	 required_updates_for_style (MStyle *style);
-StyleHAlignFlags style_default_halign (MStyle const *mstyle, Cell const *c);
+SpanCalcFlags	 required_updates_for_style (GnmStyle *style);
+StyleHAlignFlags style_default_halign (GnmStyle const *mstyle, GnmCell const *c);
 
 extern double gnumeric_default_font_width;
 
+GnomeFont *gnm_font_find_closest_from_weight_slant (const guchar *family, 
+						    GnomeFontWeight weight, 
+						    gboolean italic, 
+						    gdouble size);
+PangoContext *gnm_pango_context_get (void);
+
 #include "mstyle.h"
 
 #endif /* GNUMERIC_STYLE_H */
