@@ -56,7 +56,7 @@
 
 typedef struct {
 	gint n;
-	Value **values;
+	GnmValue **values;
 	gnm_float *cumul_p;
 } discrete_random_tool_local_t;
 
@@ -82,7 +82,7 @@ tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t
 					    discrete_random_tool_local_t **continuity)
 {
 	discrete_random_tool_local_t *data;
-	Value *range = param->range;
+	GnmValue *range = param->range;
 	gnm_float cumprob = 0;
 	int j = 0;
 	int i;
@@ -90,20 +90,20 @@ tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t
 	data = *continuity = g_new0 (discrete_random_tool_local_t, 1);
 	data->n = range->v_range.cell.b.row - range->v_range.cell.a.row + 1;
 	data->cumul_p = g_new (gnm_float, data->n);
-	data->values = g_new0 (Value *, data->n);
+	data->values = g_new0 (GnmValue *, data->n);
 
 	for (i = range->v_range.cell.a.row;
 	     i <= range->v_range.cell.b.row;
 	     i++, j++) {
-		Value *v;
+		GnmValue *v;
 		gnm_float thisprob;
-		Cell *cell = sheet_cell_get (range->v_range.cell.a.sheet,
+		GnmCell *cell = sheet_cell_get (range->v_range.cell.a.sheet,
 					     range->v_range.cell.a.col + 1, i);
 
 		if (cell == NULL ||
 		    (v = cell->value) == NULL ||
 		    !VALUE_IS_NUMBER (v)) {
-			gnumeric_error_calc (COMMAND_CONTEXT (info->wbc),
+			gnm_cmd_context_error_calc (GNM_CMD_CONTEXT (info->wbc),
 					 _("The probability input range "
 					   "contains a non-numeric value.\n"
 					   "All probabilities must be "
@@ -111,7 +111,7 @@ tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t
 			goto random_tool_discrete_out;
 		}
 		if ((thisprob = value_get_as_float (v)) < 0) {
-			gnumeric_error_calc (COMMAND_CONTEXT (info->wbc),
+			gnm_cmd_context_error_calc (GNM_CMD_CONTEXT (info->wbc),
 					 _("The probability input range "
 					   "contains a negative number.\n"
 					   "All probabilities must be "
@@ -126,13 +126,13 @@ tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t
 				       range->v_range.cell.a.col, i);
 
 		if (cell == NULL || cell->value == NULL) {
-			gnumeric_error_calc (COMMAND_CONTEXT (info->wbc),
+			gnm_cmd_context_error_calc (GNM_CMD_CONTEXT (info->wbc),
 					 _("None of the values in the value "
 					   "range may be empty!"));
 			goto random_tool_discrete_out;
 		}
 
-		data->values[j] = value_duplicate (cell->value);
+		data->values[j] = value_dup (cell->value);
 	}
 
 	if (cumprob != 0) {
@@ -142,7 +142,7 @@ tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t
 		}
 		return FALSE;
 	}
-	gnumeric_error_calc (COMMAND_CONTEXT (info->wbc),
+	gnm_cmd_context_error_calc (GNM_CMD_CONTEXT (info->wbc),
 			 _("The probabilities may not all be 0!"));
 
  random_tool_discrete_out:
@@ -169,7 +169,7 @@ tool_random_engine_run_discrete (data_analysis_output_t *dao,
 				;
 
 			dao_set_cell_value (dao, i, k,
-					    value_duplicate (data->values[j]));
+					    value_dup (data->values[j]));
 		}
 	}
 	tool_random_engine_run_discrete_clear_continuity (continuity);
