@@ -35,11 +35,12 @@
 #include "pixmaps/gnumeric-stock-pixbufs.h"
 #include "widgets/gnumeric-combo-text.h"
 
-#include <widgets/gtk-combo-box.h>
+#include <widgets/gnm-combo-box.h>
 #include <widgets/widget-color-combo.h>
 #include <widgets/widget-pixmap-combo.h>
 #include <libgnomeui/gnome-app-helper.h>
 #include <libgnomeui/gnome-stock-icons.h>
+#include <gtk/gtktogglebutton.h>
 
 #include <string.h>
 
@@ -61,7 +62,7 @@ set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView	*wb_view;
-	MStyle *style;
+	GnmStyle *style;
 
 	/* If the user did not initiate this action ignore it.
 	 * This happens whenever the ui updates and the current cell makes a
@@ -70,7 +71,7 @@ set_selection_halign (WorkbookControlGUI *wbcg, StyleHAlignFlags halign)
 	if (wbcg->updating_ui)
 		return;
 
-	application_clipboard_unant ();
+	gnm_app_clipboard_unant ();
 
 	/* This is a toggle button.  If we are already enabled
 	 * then revert to general
@@ -150,7 +151,7 @@ change_selection_font (WorkbookControlGUI *wbcg,
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	Sheet *sheet = wb_control_cur_sheet (wbc);
 	SheetView *sv = wb_control_cur_sheet_view (wbc);
-	MStyle *new_style, *current_style;
+	GnmStyle *new_style, *current_style;
 
 	/* If the user did not initiate this action ignore it.
 	 * This happens whenever the ui updates and the current cell makes a
@@ -159,7 +160,7 @@ change_selection_font (WorkbookControlGUI *wbcg,
 	if (wbcg->updating_ui)
 		return;
 
-	application_clipboard_unant ();
+	gnm_app_clipboard_unant ();
 
 	new_style = mstyle_new ();
 	current_style = sheet_style_get (sheet,
@@ -246,7 +247,7 @@ change_font_in_selection_cmd (GnmComboText *ct, char const *font_name,
 		return TRUE;
 
 	if (sheet != NULL) {
-		MStyle *mstyle;
+		GnmStyle *mstyle;
 
 		mstyle = mstyle_new ();
 		mstyle_set_font_name (mstyle, font_name);
@@ -265,7 +266,7 @@ change_font_size_in_selection_cmd (GnmComboText *ct, char const *sizetext,
 				   WorkbookControlGUI *wbcg)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 	double size;
 
 	/* If the user did not initiate this action ignore it.
@@ -298,7 +299,7 @@ apply_number_format (WorkbookControlGUI *wbcg,
 		     char const *translated_format, char const *descriptor)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	MStyle *mstyle = mstyle_new ();
+	GnmStyle *mstyle = mstyle_new ();
 
 	mstyle_set_format_text (mstyle, translated_format);
 	cmd_selection_format (wbc, mstyle, NULL, descriptor);
@@ -319,12 +320,12 @@ cb_format_as_percent (GtkWidget *ignore, WorkbookControlGUI *wbcg)
 
 static void
 modify_format (WorkbookControlGUI *wbcg,
-	       StyleFormat *(*format_modify_fn) (StyleFormat const *format),
+	       GnmFormat *(*format_modify_fn) (GnmFormat const *format),
 	       char const *descriptor)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	WorkbookView const *wbv;
-	StyleFormat *new_fmt;
+	GnmFormat *new_fmt;
 
 	wbv = wb_control_view (wbc);
 	g_return_if_fail (wbv != NULL);
@@ -332,7 +333,7 @@ modify_format (WorkbookControlGUI *wbcg,
 
 	new_fmt = (*format_modify_fn) (mstyle_get_format (wbv->current_format));
 	if (new_fmt != NULL) {
-		MStyle *style = mstyle_new ();
+		GnmStyle *style = mstyle_new ();
 		mstyle_set_format (style, new_fmt);
 		cmd_selection_format (wbc, style, NULL, descriptor);
 		style_format_unref (new_fmt);
@@ -370,7 +371,7 @@ cb_format_inc_indent (GtkWidget *ignore, WorkbookControlGUI *wbcg)
 
 	i = mstyle_get_indent (wbv->current_format);
 	if (i < 20) {
-		MStyle *style = mstyle_new ();
+		GnmStyle *style = mstyle_new ();
 
 		if (HALIGN_LEFT != mstyle_get_align_h (wbv->current_format))
 			mstyle_set_align_h (style, HALIGN_LEFT);
@@ -393,7 +394,7 @@ cb_format_dec_indent (GtkWidget *ignore, WorkbookControlGUI *wbcg)
 
 	i = mstyle_get_indent (wbv->current_format);
 	if (i > 0) {
-		MStyle *style = mstyle_new ();
+		GnmStyle *style = mstyle_new ();
 
 		mstyle_set_indent (style, i-1);
 		cmd_selection_format (wbc, style, NULL,
@@ -516,7 +517,7 @@ cb_fore_color_changed (ColorCombo *combo, GdkColor *c,
 		       WorkbookControlGUI *wbcg)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 
 	/* Color was set programatically, bail out */
 	if (!by_user)
@@ -553,7 +554,7 @@ cb_back_color_changed (ColorCombo *combo, GdkColor *c,
 		       WorkbookControlGUI *wbcg)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 
 	/* Color was set programatically, bail out */
 	if (!by_user)
@@ -649,7 +650,7 @@ static void
 cb_border_changed (PixmapCombo *pixmap_combo, int index, WorkbookControlGUI *wbcg)
 {
 	Sheet *sheet = wb_control_cur_sheet (WORKBOOK_CONTROL (wbcg));
-	StyleBorder *borders[STYLE_BORDER_EDGE_MAX];
+	GnmBorder *borders[STYLE_BORDER_EDGE_MAX];
 	int i;
 
 	/* Init the list */
@@ -734,7 +735,7 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 	GtkWidget *fontsel, *fontsize, *entry;
 	GtkWidget *border_combo, *back_combo, *fore_combo;
 	ColorGroup *cg;
-	StyleColor *sc_auto_font = style_color_auto_font ();
+	GnmColor *sc_auto_font = style_color_auto_font ();
 
 	GList *l;
 	int i, len;
@@ -753,7 +754,7 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 			  "entry_changed",
 			  G_CALLBACK (change_font_in_selection_cmd), wbcg);
 	entry = GNM_COMBO_TEXT (fontsel)->entry;
-	/* gtk_combo_box_set_title (GTK_COMBO_BOX (fontsel), _("Font")); */
+	/* gnm_combo_box_set_title (GNM_COMBO_BOX (fontsel), _("Font")); */
 	/* gtk_container_set_border_width (GTK_CONTAINER (fontsel), 0); */
 
 	len = 0;
@@ -777,7 +778,7 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 			  "entry_changed",
 			  G_CALLBACK (change_font_size_in_selection_cmd), wbcg);
 	entry = GNM_COMBO_TEXT (fontsize)->entry;
-	/* gtk_combo_box_set_title (GTK_COMBO_BOX (fontsize), _("Size"));  */
+	/* gnm_combo_box_set_title (GNM_COMBO_BOX (fontsize), _("Size"));  */
 	for (i = 0; gnumeric_point_sizes[i] != 0; i++) {
 		char *buffer = g_strdup_printf ("%d", gnumeric_point_sizes[i]);
 		gnm_combo_text_add_item (GNM_COMBO_TEXT (fontsize), buffer);
@@ -791,7 +792,7 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 				     -1);
 
 	/* Border combo box */
-	border_combo = pixmap_combo_new (border_combo_info, 3, 4);
+	border_combo = pixmap_combo_new (border_combo_info, 3, 4, TRUE);
 
 	/* default to none */
 	pixmap_combo_select_pixmap (PIXMAP_COMBO (border_combo), 1);
@@ -799,13 +800,13 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 		"changed",
 		G_CALLBACK (cb_border_changed), wbcg);
 	disable_focus (border_combo, NULL);
-	gtk_combo_box_set_title (GTK_COMBO_BOX (border_combo),
+	gnm_combo_box_set_title (GNM_COMBO_BOX (border_combo),
 				 _("Borders"));
 
 	/* Create the background colour combo box */
 	cg = color_group_fetch ("back_color_group", wb_control_view (WORKBOOK_CONTROL (wbcg)));
 	wbcg->back_color = back_combo = color_combo_new (
-		application_get_pixbuf ("bucket"),
+		gnm_app_get_pixbuf ("bucket"),
 		_("Clear Background"),
 		/* Draw an outline for the default */
 		NULL, cg);
@@ -813,7 +814,7 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 		"color_changed",
 		G_CALLBACK (cb_back_color_changed), wbcg);
 	disable_focus (back_combo, NULL);
-	gtk_combo_box_set_title (GTK_COMBO_BOX (back_combo),
+	gnm_combo_box_set_title (GNM_COMBO_BOX (back_combo),
 				 _("Background"));
 
 	/* Sync the color of the background color combo with the other views */
@@ -832,13 +833,13 @@ workbook_create_format_toolbar (WorkbookControlGUI *wbcg)
 	/* Create the font colour combo box.  */
 	cg = color_group_fetch ("fore_color_group", wb_control_view (WORKBOOK_CONTROL (wbcg)));
 	wbcg->fore_color = fore_combo = color_combo_new (
-		application_get_pixbuf ("font"),
+		gnm_app_get_pixbuf ("font"),
 		_("Automatic"),	&sc_auto_font->color, cg);
 	g_signal_connect (G_OBJECT (fore_combo),
 		"color_changed",
 		G_CALLBACK (cb_fore_color_changed), wbcg);
 	disable_focus (fore_combo, NULL);
-	gtk_combo_box_set_title (GTK_COMBO_BOX (fore_combo),
+	gnm_combo_box_set_title (GNM_COMBO_BOX (fore_combo),
 				 _("Foreground"));
 
 	/* Sync the color of the font color combo with the other views */
@@ -973,7 +974,7 @@ workbook_feedback_set (WorkbookControlGUI *wbcg)
 #ifndef WITH_BONOBO
 	GtkToolbar *toolbar;
 #endif
-	MStyle 		*style;
+	GnmStyle 		*style;
 	GnmComboText    *fontsel;
 	GnmComboText    *fontsize;
 	WorkbookView	*wb_view = wb_control_view (WORKBOOK_CONTROL (wbcg));
